@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -28,7 +28,7 @@
  * Author  : Czo <Olivier.Sirol@lip6.fr>
  */
 
-#ident "$Id: alcbanner.c,v 1.3 2002/09/30 16:19:42 czo Exp $"
+#ident "$Id: alcbanner.c,v 1.4 2012/05/14 14:19:52 alliance Exp $"
 
 
 /*
