@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: attila.sh,v 1.25 2008/07/15 16:45:28 xtof Exp $
+# $Id: attila.sh,v 1.27 2012/04/11 13:30:29 alliance Exp $
 #                                                                        
 # /------------------------------------------------------------------\
 # |                                                                  |
@@ -14,6 +14,12 @@
 # | **************************************************************** |
 # |  U p d a t e s                                                   |
 # | $Log: attila.sh,v $
+# | Revision 1.27  2012/04/11 13:30:29  alliance
+# | Small adjustments.
+# |
+# | Revision 1.26  2012/01/02 22:30:19  jpc
+# | Added support for Scientific Linux 6.
+# |
 # | Revision 1.25  2008/07/15 16:45:28  xtof
 # | do not use Solaris anymore
 # |
@@ -213,9 +219,13 @@
      Linux*EL*i686*)    echo "Linux.SLA4x";;
      Linux*EL*x86_64*)  echo "Linux.SLA4x_64";;
      Linux*2.6.16*FC5*) echo "Linux.SLA4x";;
+     Linux*el5*x86_64)  echo "Linux.SLSoC5x_64";;
      Linux*el5*)        echo "Linux.SLSoC5x";;
      Linux*SLSoC5*)     echo "Linux.SLSoC5x";;
      Linux*el5*x86_64)  echo "Linux.SLSoC5x_64";;
+     Linux*el6*x86_64)  echo "Linux.slsoc6x_64";;
+     Linux*slsoc6*)     echo "Linux.slsoc6x";;
+     Linux*el6*)        echo "Linux.slsoc6x";;
      Linux*i686*)       echo "Linux.i686";;
      SunOS\ 5*)         echo "Solaris";;
      Darwin*)           echo "Darwin";;
@@ -232,6 +242,16 @@
  guess_gcc ()
  {
    case "$1" in
+     "Linux.slsoc6x")    if which gcc > /dev/null 2>&1; then
+                           CXX=$LINUX_slsoc6x_CXX
+                            CC=$LINUX_slsoc6x_CC
+                         fi
+                         ;;
+     "Linux.slsoc6x_64") if which gcc > /dev/null 2>&1; then
+                           CXX=$LINUX_slsoc6x_64_CXX
+                            CC=$LINUX_slsoc6x_64_CC
+                         fi
+                         ;;
      "Linux.SLSoC5x")    if which gcc > /dev/null 2>&1; then
                            CXX=$LINUX_SLSoC5x_CXX
                             CC=$LINUX_SLSoC5x_CC
@@ -479,6 +499,8 @@
    echo "  o  Compilation environment."
 
    case "$ALLIANCE_OS" in
+     "Linux.slsoc6x_64")  MAKE="make";;
+     "Linux.slsoc6x")     MAKE="make";;
      "Linux.SLSoC5x_64")  MAKE="make";;
      "Linux.SLSoC5x")     MAKE="make";;
      "Linux.SLA4x")       MAKE="make";;
@@ -592,7 +614,13 @@
        echo "     - Adding dynamic link support for ASIM install"
        ARGS_CONFIGURE="$ARGS_CONFIGURE --enable-alc-shared"
      fi
-     $SRC_DIR/$TOOL/configure --prefix=$INSTALL_DIR $ARGS_CONFIGURE
+     ARGS_CONFIGURE="$ARGS_CONFIGURE --enable-alc-shared --disable-static"
+     $SRC_DIR/$TOOL/configure --prefix=$INSTALL_DIR \
+                              --mandir=$INSTALL_DIR/man \
+                                CFLAGS="-I$ALLIANCE_TOP/include" \
+                              CXXFLAGS="-I$ALLIANCE_TOP/include" \
+                               LDFLAGS="-L$ALLIANCE_TOP/lib" \
+                              --enable-alc-shared
      $MAKE prefix=$INSTALL_DIR $ARGS_MAKE
 
      cd ..
@@ -623,11 +651,19 @@
 
    CVS_STARTUP_FILES=""
 
+  LINUX_slsoc6x_64_TARGET="coriolis"
+      LINUX_slsoc6x_64_CC="gcc"
+     LINUX_slsoc6x_64_CXX="g++"
+
+     LINUX_slsoc6x_TARGET="yo35"
+         LINUX_slsoc6x_CC="gcc"
+        LINUX_slsoc6x_CXX="g++"
+
   LINUX_SLSoC5x_64_TARGET="coriolis"
       LINUX_SLSoC5x_64_CC="gcc"
      LINUX_SLASoC5_64_CXX="g++"
 
-     LINUX_SLSoC5x_TARGET="bip"
+     LINUX_SLSoC5x_TARGET="stixo"
          LINUX_SLSoC5x_CC="gcc"
         LINUX_SLASoC5_CXX="g++"
 
@@ -656,7 +692,7 @@
 # Internal variables.
 
 
-             ALL_OSS="Linux.SLSoC5x Linux.SLA4x Solaris"
+             ALL_OSS="Linux.SLSoC5x_64 Linux.SLSoC5x Linux.SLA4x Solaris"
                   CC=gcc
                  CXX=g++
               export CC CXX
@@ -834,9 +870,9 @@
    ENVIRONMENT=""
    ENVIRONMENT="$ENVIRONMENT ALLIANCE_TOP=$ALLIANCE_TOP; export ALLIANCE_TOP;"
 
-  #$RSH $LINUX_SLSoC5x_64_TARGET "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
    $RSH $LINUX_SLSoC5x_TARGET    "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
-   $RSH $LINUX_SLA4x_TARGET      "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
+   $RSH $LINUX_SLSoC5x_64_TARGET "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
+  #$RSH $LINUX_SLA4x_TARGET      "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
   #$RSH $LINUX_FC2_TARGET        "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
   #$RSH $LINUX_RH71_TARGET       "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
   #$RSH $SOLARIS_TARGET          "/bin/bash -c \". /etc/profile; $ENVIRONMENT $SELF $ARGS\""
