@@ -18,7 +18,7 @@
  *
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -150,7 +150,7 @@ static int distribCell(befig_list* befig)
          }
 
          /*patterns aren't equal, new is more precise*/
-         if (!biabl_befig) break;
+         if (!biabl_befig) continue;
          
          /*patterns are equal -->comparison*/
          if (cell->AREA<getgenericarea(befig)) return 0;  /*don't use the new*/
@@ -224,7 +224,7 @@ static int distribCell(befig_list* befig)
          }
 
          /*patterns aren't equal, new is more precise*/
-         if (!biabl_befig) break;
+         if (biabl_befig) continue;
          
          /*patterns are equal -->comparison*/
          if (cell->AREA<getgenericarea(befig)) return 0;  /*don't use the new*/
