@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define VRD_Y_BISON 1
 
 /* Bison version.  */
-#define VRD_Y_BISON_VERSION "2.3"
+#define VRD_Y_BISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define VRD_Y_SKELETON_NAME "yacc.c"
@@ -55,11 +54,79 @@
 /* Pure parsers.  */
 #define VRD_Y_PURE 0
 
+/* Push parsers.  */
+#define VRD_Y_PUSH 0
+
+/* Pull parsers.  */
+#define VRD_Y_PULL 1
+
 /* Using locations.  */
 #define VRD_Y_LSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "./drucompi_y.y"
+
+#include <stdio.h>
+#include "mph.h"
+#include "mut.h"
+#include "rds.h"
+#include "rwi.h"
+#include "rut.h"
+#include "rtl.h"
+#include "rfm.h"
+#include "rpr.h"
+#include "drucutil.h"
+#include "drucompi.h"
+
+/*------------------------------------------------------------\
+|                                                             |
+|                  Druc MODIFICATIONS                         |
+|                                                             |
+|  Patrick: 07/03/94                                          |
+|    Ajouter DRUC_FRONTALE et DRUC_LATERALE_MIN               |
+|    qui etaient oublies dans les derivations                 |
+|                                                             |
+\------------------------------------------------------------*/
+/*------------------------------------------------------------\
+|                                                             |
+|                  Druc Variables LEX/YACC                    |
+|                                                             |
+\------------------------------------------------------------*/
+extern int   vrd_y_lineno;
+extern FILE *vrd_y_in;
+       int   DrucIndexMesure;
+       int   DrucInputEntier;
+       int   DrucNegatif;
+       float DrucInputFloat;
+       char  DrucInputChaine[DRUC_MAX_STRING_BUFFER + 1];
+
+
+/* Line 189 of yacc.c  */
+#line 110 "y.tab.c"
+
+/* Enabling traces.  */
+#ifndef VRD_Y_DEBUG
+# define VRD_Y_DEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef VRD_Y_ERROR_VERBOSE
+# undef VRD_Y_ERROR_VERBOSE
+# define VRD_Y_ERROR_VERBOSE 1
+#else
+# define VRD_Y_ERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef VRD_Y_TOKEN_TABLE
+# define VRD_Y_TOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef VRD_Y_TOKENTYPE
 # define VRD_Y_TOKENTYPE
@@ -171,76 +238,19 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "../../../src/druc/src/drucompi_y.y"
-
-#include <stdio.h>
-#include "mph.h"
-#include "mut.h"
-#include "rds.h"
-#include "rwi.h"
-#include "rut.h"
-#include "rtl.h"
-#include "rfm.h"
-#include "rpr.h"
-#include "drucutil.h"
-#include "drucompi.h"
-
-/*------------------------------------------------------------\
-|                                                             |
-|                  Druc MODIFICATIONS                         |
-|                                                             |
-|  Patrick: 07/03/94                                          |
-|    Ajouter DRUC_FRONTALE et DRUC_LATERALE_MIN               |
-|    qui etaient oublies dans les derivations                 |
-|                                                             |
-\------------------------------------------------------------*/
-/*------------------------------------------------------------\
-|                                                             |
-|                  Druc Variables LEX/YACC                    |
-|                                                             |
-\------------------------------------------------------------*/
-extern int   vrd_y_lineno;
-extern FILE *vrd_y_in;
-       int   DrucIndexMesure;
-       int   DrucInputEntier;
-       int   DrucNegatif;
-       float DrucInputFloat;
-       char  DrucInputChaine[DRUC_MAX_STRING_BUFFER + 1];
-
-
-/* Enabling traces.  */
-#ifndef VRD_Y_DEBUG
-# define VRD_Y_DEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef VRD_Y_ERROR_VERBOSE
-# undef VRD_Y_ERROR_VERBOSE
-# define VRD_Y_ERROR_VERBOSE 1
-#else
-# define VRD_Y_ERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef VRD_Y_TOKEN_TABLE
-# define VRD_Y_TOKEN_TABLE 0
-#endif
-
 #if ! defined VRD_Y_STYPE && ! defined VRD_Y_STYPE_IS_DECLARED
 typedef int VRD_Y_STYPE;
+# define VRD_Y_STYPE_IS_TRIVIAL 1
 # define vrd_y_stype VRD_Y_STYPE /* obsolescent; will be withdrawn */
 # define VRD_Y_STYPE_IS_DECLARED 1
-# define VRD_Y_STYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 244 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 254 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -315,14 +325,14 @@ typedef short int vrd_y_type_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-VRD_Y_ID (int i)
+VRD_Y_ID (int vrd_y_i)
 #else
 static int
-VRD_Y_ID (i)
-    int i;
+VRD_Y_ID (vrd_y_i)
+    int vrd_y_i;
 #endif
 {
-  return i;
+  return vrd_y_i;
 }
 #endif
 
@@ -403,9 +413,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union vrd_y_alloc
 {
-  vrd_y_type_int16 vrd_y_ss;
-  VRD_Y_STYPE vrd_y_vs;
-  };
+  vrd_y_type_int16 vrd_y_ss_alloc;
+  VRD_Y_STYPE vrd_y_vs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define VRD_Y_STACK_GAP_MAXIMUM (sizeof (union vrd_y_alloc) - 1)
@@ -439,12 +449,12 @@ union vrd_y_alloc
    elements in the stack, and VRD_Y_PTR gives the new location of the
    stack.  Advance VRD_Y_PTR to a properly aligned location for the next
    stack.  */
-# define VRD_Y_STACK_RELOCATE(Stack)					\
+# define VRD_Y_STACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	VRD_Y_SIZE_T vrd_y_newbytes;						\
-	VRD_Y_COPY (&vrd_y_ptr->Stack, Stack, vrd_y_size);				\
-	Stack = &vrd_y_ptr->Stack;						\
+	VRD_Y_COPY (&vrd_y_ptr->Stack_alloc, Stack, vrd_y_size);			\
+	Stack = &vrd_y_ptr->Stack_alloc;					\
 	vrd_y_newbytes = vrd_y_stacksize * sizeof (*Stack) + VRD_Y_STACK_GAP_MAXIMUM; \
 	vrd_y_ptr += vrd_y_newbytes / sizeof (*vrd_y_ptr);				\
       }									\
@@ -589,12 +599,12 @@ static const char *const vrd_y_tname[] =
   "DRUC_MIN", "DRUC_MAX", "DRUC_INFEQ", "DRUC_SUPEQ", "DRUC_DIFF",
   "DRUC_NOTCH", "DRUC_DESTINATION", "DRUC_ENTIER", "DRUC_FLOAT",
   "DRUC_NEG_FLOAT", "';'", "','", "'('", "')'", "':'", "'<'", "'>'", "'='",
-  "$accept", "drc", "@1", "list_layer", "layer", "@2", "@3", "list_bloc",
-  "bloc", "define", "@4", "@5", "resiz", "@6", "valresiz", "defoper", "@7",
-  "@8", "compose", "defmodif", "undefine", "@9", "caracter", "@10",
-  "lst_rgl_1", "regle_1", "@11", "@12", "@13", "relation", "@14", "@15",
-  "@16", "lst_rgl_2", "regle_2", "@17", "@18", "@19", "config",
-  "mesure_rel", "mesure", "compar", 0
+  "$accept", "drc", "$@1", "list_layer", "layer", "$@2", "$@3",
+  "list_bloc", "bloc", "define", "$@4", "$@5", "resiz", "$@6", "valresiz",
+  "defoper", "$@7", "$@8", "compose", "defmodif", "undefine", "$@9",
+  "caracter", "$@10", "lst_rgl_1", "regle_1", "$@11", "$@12", "$@13",
+  "relation", "$@14", "$@15", "$@16", "lst_rgl_2", "regle_2", "$@17",
+  "$@18", "$@19", "config", "mesure_rel", "mesure", "compar", 0
 };
 #endif
 
@@ -941,17 +951,20 @@ vrd_y__symbol_print (vrd_y_output, vrd_y_type, vrd_y_valuep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-vrd_y__stack_print (vrd_y_type_int16 *bottom, vrd_y_type_int16 *top)
+vrd_y__stack_print (vrd_y_type_int16 *vrd_y_bottom, vrd_y_type_int16 *vrd_y_top)
 #else
 static void
-vrd_y__stack_print (bottom, top)
-    vrd_y_type_int16 *bottom;
-    vrd_y_type_int16 *top;
+vrd_y__stack_print (vrd_y_bottom, vrd_y_top)
+    vrd_y_type_int16 *vrd_y_bottom;
+    vrd_y_type_int16 *vrd_y_top;
 #endif
 {
   VRD_Y_FPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    VRD_Y_FPRINTF (stderr, " %d", *bottom);
+  for (; vrd_y_bottom <= vrd_y_top; vrd_y_bottom++)
+    {
+      int vrd_y_bot = *vrd_y_bottom;
+      VRD_Y_FPRINTF (stderr, " %d", vrd_y_bot);
+    }
   VRD_Y_FPRINTF (stderr, "\n");
 }
 
@@ -985,11 +998,11 @@ vrd_y__reduce_print (vrd_y_vsp, vrd_y_rule)
   /* The symbols being reduced.  */
   for (vrd_y_i = 0; vrd_y_i < vrd_y_nrhs; vrd_y_i++)
     {
-      fprintf (stderr, "   $%d = ", vrd_y_i + 1);
+      VRD_Y_FPRINTF (stderr, "   $%d = ", vrd_y_i + 1);
       vrd_y__symbol_print (stderr, vrd_y_rhs[vrd_y_prhs[vrd_y_rule] + vrd_y_i],
 		       &(vrd_y_vsp[(vrd_y_i + 1) - (vrd_y_nrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      VRD_Y_FPRINTF (stderr, "\n");
     }
 }
 
@@ -1269,10 +1282,8 @@ vrd_y_destruct (vrd_y_msg, vrd_y_type, vrd_y_valuep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef VRD_Y_PARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int vrd_y_parse (void *VRD_Y_PARSE_PARAM);
@@ -1288,11 +1299,10 @@ int vrd_y_parse ();
 #endif /* ! VRD_Y_PARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int vrd_y_char;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 VRD_Y_STYPE vrd_y_lval;
 
 /* Number of syntax errors so far.  */
@@ -1300,9 +1310,9 @@ int vrd_y_nerrs;
 
 
 
-/*----------.
-| vrd_y_parse.  |
-`----------*/
+/*-------------------------.
+| vrd_y_parse or vrd_y_push_parse.  |
+`-------------------------*/
 
 #ifdef VRD_Y_PARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1326,14 +1336,39 @@ vrd_y_parse ()
 #endif
 #endif
 {
-  
-  int vrd_y_state;
+
+
+    int vrd_y_state;
+    /* Number of tokens to shift before error messages enabled.  */
+    int vrd_y_errstatus;
+
+    /* The stacks and their tools:
+       `vrd_y_ss': related to states.
+       `vrd_y_vs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow vrd_y_overflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    vrd_y_type_int16 vrd_y_ssa[VRD_Y_INITDEPTH];
+    vrd_y_type_int16 *vrd_y_ss;
+    vrd_y_type_int16 *vrd_y_ssp;
+
+    /* The semantic value stack.  */
+    VRD_Y_STYPE vrd_y_vsa[VRD_Y_INITDEPTH];
+    VRD_Y_STYPE *vrd_y_vs;
+    VRD_Y_STYPE *vrd_y_vsp;
+
+    VRD_Y_SIZE_T vrd_y_stacksize;
+
   int vrd_y_n;
   int vrd_y_result;
-  /* Number of tokens to shift before error messages enabled.  */
-  int vrd_y_errstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int vrd_y_token = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int vrd_y_token;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  VRD_Y_STYPE vrd_y_val;
+
 #if VRD_Y_ERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char vrd_y_msgbuf[128];
@@ -1341,51 +1376,28 @@ vrd_y_parse ()
   VRD_Y_SIZE_T vrd_y_msg_alloc = sizeof vrd_y_msgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `vrd_y_ss': related to states,
-     `vrd_y_vs': related to semantic values,
-     `vrd_y_ls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow vrd_y_overflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  vrd_y_type_int16 vrd_y_ssa[VRD_Y_INITDEPTH];
-  vrd_y_type_int16 *vrd_y_ss = vrd_y_ssa;
-  vrd_y_type_int16 *vrd_y_ssp;
-
-  /* The semantic value stack.  */
-  VRD_Y_STYPE vrd_y_vsa[VRD_Y_INITDEPTH];
-  VRD_Y_STYPE *vrd_y_vs = vrd_y_vsa;
-  VRD_Y_STYPE *vrd_y_vsp;
-
-
-
 #define VRD_Y_POPSTACK(N)   (vrd_y_vsp -= (N), vrd_y_ssp -= (N))
 
-  VRD_Y_SIZE_T vrd_y_stacksize = VRD_Y_INITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  VRD_Y_STYPE vrd_y_val;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int vrd_y_len = 0;
 
+  vrd_y_token = 0;
+  vrd_y_ss = vrd_y_ssa;
+  vrd_y_vs = vrd_y_vsa;
+  vrd_y_stacksize = VRD_Y_INITDEPTH;
+
   VRD_Y_DPRINTF ((stderr, "Starting parse\n"));
 
   vrd_y_state = 0;
   vrd_y_errstatus = 0;
   vrd_y_nerrs = 0;
-  vrd_y_char = VRD_Y_EMPTY;		/* Cause a token to be read.  */
+  vrd_y_char = VRD_Y_EMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   vrd_y_ssp = vrd_y_ss;
   vrd_y_vsp = vrd_y_vs;
 
@@ -1415,7 +1427,6 @@ vrd_y_parse ()
 	VRD_Y_STYPE *vrd_y_vs1 = vrd_y_vs;
 	vrd_y_type_int16 *vrd_y_ss1 = vrd_y_ss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1423,7 +1434,6 @@ vrd_y_parse ()
 	vrd_y_overflow (VRD_Y__("memory exhausted"),
 		    &vrd_y_ss1, vrd_y_size * sizeof (*vrd_y_ssp),
 		    &vrd_y_vs1, vrd_y_size * sizeof (*vrd_y_vsp),
-
 		    &vrd_y_stacksize);
 
 	vrd_y_ss = vrd_y_ss1;
@@ -1446,9 +1456,8 @@ vrd_y_parse ()
 	  (union vrd_y_alloc *) VRD_Y_STACK_ALLOC (VRD_Y_STACK_BYTES (vrd_y_stacksize));
 	if (! vrd_y_ptr)
 	  goto vrd_y_exhaustedlab;
-	VRD_Y_STACK_RELOCATE (vrd_y_ss);
-	VRD_Y_STACK_RELOCATE (vrd_y_vs);
-
+	VRD_Y_STACK_RELOCATE (vrd_y_ss_alloc, vrd_y_ss);
+	VRD_Y_STACK_RELOCATE (vrd_y_vs_alloc, vrd_y_vs);
 #  undef VRD_Y_STACK_RELOCATE
 	if (vrd_y_ss1 != vrd_y_ssa)
 	  VRD_Y_STACK_FREE (vrd_y_ss1);
@@ -1459,7 +1468,6 @@ vrd_y_parse ()
       vrd_y_ssp = vrd_y_ss + vrd_y_size - 1;
       vrd_y_vsp = vrd_y_vs + vrd_y_size - 1;
 
-
       VRD_Y_DPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) vrd_y_stacksize));
 
@@ -1469,6 +1477,9 @@ vrd_y_parse ()
 
   VRD_Y_DPRINTF ((stderr, "Entering state %d\n", vrd_y_state));
 
+  if (vrd_y_state == VRD_Y_FINAL)
+    VRD_Y_ACCEPT;
+
   goto vrd_y_backup;
 
 /*-----------.
@@ -1477,16 +1488,16 @@ vrd_y_parse ()
 vrd_y_backup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   vrd_y_n = vrd_y_pact[vrd_y_state];
   if (vrd_y_n == VRD_Y_PACT_NINF)
     goto vrd_y_default;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* VRD_Y_CHAR is either VRD_Y_EMPTY or VRD_Y_EOF or a valid look-ahead symbol.  */
+  /* VRD_Y_CHAR is either VRD_Y_EMPTY or VRD_Y_EOF or a valid lookahead symbol.  */
   if (vrd_y_char == VRD_Y_EMPTY)
     {
       VRD_Y_DPRINTF ((stderr, "Reading a token: "));
@@ -1518,20 +1529,16 @@ vrd_y_backup:
       goto vrd_y_reduce;
     }
 
-  if (vrd_y_n == VRD_Y_FINAL)
-    VRD_Y_ACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (vrd_y_errstatus)
     vrd_y_errstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   VRD_Y__SYMBOL_PRINT ("Shifting", vrd_y_token, &vrd_y_lval, &vrd_y_lloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (vrd_y_char != VRD_Y_EOF)
-    vrd_y_char = VRD_Y_EMPTY;
+  /* Discard the shifted token.  */
+  vrd_y_char = VRD_Y_EMPTY;
 
   vrd_y_state = vrd_y_n;
   *++vrd_y_vsp = vrd_y_lval;
@@ -1571,407 +1578,548 @@ vrd_y_reduce:
   switch (vrd_y_n)
     {
         case 2:
-#line 93 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 93 "./drucompi_y.y"
     { DrucNombreInstructions = 0;
                                DrucInitCompiler () ;}
     break;
 
   case 3:
-#line 99 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 99 "./drucompi_y.y"
     { return ;}
     break;
 
   case 6:
-#line 107 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 107 "./drucompi_y.y"
     { DrucInitRdsLayerName ( DrucInputChaine ) ;}
     break;
 
   case 7:
-#line 108 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 108 "./drucompi_y.y"
     { DrucInitRdsLayerDef ( RprTranslateParam ( DrucInputFloat ) );}
     break;
 
   case 11:
-#line 117 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 117 "./drucompi_y.y"
     { DrucLoadInstructionDefine () ;}
     break;
 
   case 12:
-#line 118 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 118 "./drucompi_y.y"
     { DrucLoadInstructionUndefine () ;}
     break;
 
   case 13:
-#line 119 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 119 "./drucompi_y.y"
     { DrucLoadInstructionRegle () ;}
     break;
 
   case 14:
-#line 120 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 120 "./drucompi_y.y"
     { DrucLoadInstructionRegle () ;}
     break;
 
   case 15:
-#line 124 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 124 "./drucompi_y.y"
     { DrucInitDefineLayerA ( DrucInputChaine ) ;}
     break;
 
   case 16:
-#line 128 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 128 "./drucompi_y.y"
     { DrucInitDefineLayerDest ( DrucInputChaine ) ;}
     break;
 
   case 19:
-#line 135 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 135 "./drucompi_y.y"
     { DrucInitDefineLayerB ( DrucInputChaine ) ;}
     break;
 
   case 21:
-#line 139 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 139 "./drucompi_y.y"
     { DrucInitDefineValeur ( RprTranslateParam ( DrucInputFloat)) ;}
     break;
 
   case 22:
-#line 140 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 140 "./drucompi_y.y"
     { long i ; 
                                i =  RprTranslateParam ( DrucInputFloat ); 
                                DrucInitDefineValeur ( i );}
     break;
 
   case 23:
-#line 145 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 145 "./drucompi_y.y"
     { DrucInitOpUnaire   ( ) ;}
     break;
 
   case 24:
-#line 146 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 146 "./drucompi_y.y"
     { DrucInitDefineLayerB ( DrucInputChaine ) ;}
     break;
 
   case 27:
-#line 151 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 151 "./drucompi_y.y"
     { DrucStructDefineOpCompose( DRUC_COMPOSE_UNION );}
     break;
 
   case 28:
-#line 152 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 152 "./drucompi_y.y"
     { DrucStructDefineOpCompose( DRUC_COMPOSE_INTERSECT );}
     break;
 
   case 29:
-#line 153 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 153 "./drucompi_y.y"
     { DrucStructDefineOpCompose( DRUC_COMPOSE_EXCLUSION );}
     break;
 
   case 30:
-#line 154 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 154 "./drucompi_y.y"
     { DrucStructDefineOpCompose( DRUC_COMPOSE_INCLUSION );}
     break;
 
   case 31:
-#line 157 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 157 "./drucompi_y.y"
     { DrucStructDefineOpCompose( DRUC_COMPOSE_RESIZE    );}
     break;
 
   case 32:
-#line 161 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 161 "./drucompi_y.y"
     { DrucInitUndefineUserLayer ( DrucInputChaine ) ;}
     break;
 
   case 34:
-#line 166 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 166 "./drucompi_y.y"
     { DrucInitRegleLayerA ( DrucInputChaine ) ;
                                DrucInitRegleInstruction ( DRUC_INSTR_CARACTERISE ) ;
                                DrucIndexMesure = -1 ;}
     break;
 
   case 38:
-#line 180 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 180 "./drucompi_y.y"
     { DrucIndexMesure ++ ;}
     break;
 
   case 39:
-#line 181 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 181 "./drucompi_y.y"
     { DrucInitRegleNumero ( DrucInputEntier,
                                                      DrucIndexMesure) ;}
     break;
 
   case 40:
-#line 186 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 186 "./drucompi_y.y"
     { DrucInitRegleValeur ( RprTranslateParam ( DrucInputFloat ),
                                                      DrucIndexMesure );}
     break;
 
   case 42:
-#line 191 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 191 "./drucompi_y.y"
     { DrucInitRegleInstruction ( DRUC_INSTR_RELATION ) ;}
     break;
 
   case 43:
-#line 192 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 192 "./drucompi_y.y"
     { DrucInitRegleLayerA ( DrucInputChaine ) ;}
     break;
 
   case 44:
-#line 194 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 194 "./drucompi_y.y"
     { DrucInitRegleLayerB ( DrucInputChaine ) ;
                                DrucIndexMesure = -1 ; }
     break;
 
   case 48:
-#line 207 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 207 "./drucompi_y.y"
     { DrucIndexMesure ++ ;}
     break;
 
   case 49:
-#line 208 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 208 "./drucompi_y.y"
     { DrucInitRegleNumero ( DrucInputEntier,
                                                      DrucIndexMesure ) ;}
     break;
 
   case 50:
-#line 214 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 214 "./drucompi_y.y"
     { DrucInitRegleValeur ( RprTranslateParam ( DrucInputFloat ),
                                                      DrucIndexMesure );}
     break;
 
   case 52:
-#line 219 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 219 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_DISTANCE,
                                                       DrucIndexMesure );}
     break;
 
   case 53:
-#line 221 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 221 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_INTERSECTION,
                                                       DrucIndexMesure );}
     break;
 
   case 54:
-#line 223 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 223 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_EXTENSION,
                                                       DrucIndexMesure );}
     break;
 
   case 55:
-#line 225 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 225 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_INCLUSION,
                                                       DrucIndexMesure );}
     break;
 
   case 56:
-#line 227 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 227 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_ENVELOPPE,
                                                       DrucIndexMesure );}
     break;
 
   case 57:
-#line 229 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 229 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_MARGE,
                                                       DrucIndexMesure );}
     break;
 
   case 58:
-#line 231 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 231 "./drucompi_y.y"
     { DrucInitRegleRelation( DRUC_RELATION_CROIX,
                                                       DrucIndexMesure );}
     break;
 
   case 59:
-#line 235 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 235 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_SURFACE_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 60:
-#line 237 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 237 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LONGUEUR_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 61:
-#line 239 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 239 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LARGEUR_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 62:
-#line 241 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 241 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_PENETRE_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 63:
-#line 243 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 243 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_PARALEL_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 64:
-#line 245 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 245 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_PERPEND_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 65:
-#line 247 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 247 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LONGUEUR_MIN,
                                                     DrucIndexMesure );}
     break;
 
   case 66:
-#line 249 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 249 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LONGUEUR_MAX,
                                                     DrucIndexMesure );}
     break;
 
   case 67:
-#line 251 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 251 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LARGEUR_MIN,
                                                     DrucIndexMesure );}
     break;
 
   case 68:
-#line 253 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 253 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LARGEUR_MAX,
                                                     DrucIndexMesure );}
     break;
 
   case 69:
-#line 255 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 255 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_FRONTALE,
                                                     DrucIndexMesure );}
     break;
 
   case 70:
-#line 257 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 257 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LATERALE_MIN,
                                                     DrucIndexMesure );}
     break;
 
   case 71:
-#line 259 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 259 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LATERALE_MAX,
                                                     DrucIndexMesure );}
     break;
 
   case 72:
-#line 261 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 261 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_SUP,
                                                     DrucIndexMesure );}
     break;
 
   case 73:
-#line 263 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 263 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_INF,
                                                     DrucIndexMesure );}
     break;
 
   case 74:
-#line 265 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 265 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_AXIALE,
                                                     DrucIndexMesure );}
     break;
 
   case 75:
-#line 267 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 267 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_GEODESIQUE,
                                                     DrucIndexMesure );}
     break;
 
   case 76:
-#line 271 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 271 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_SURFACE,
                                                     DrucIndexMesure );}
     break;
 
   case 77:
-#line 273 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 273 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LONGUEUR,
                                                     DrucIndexMesure );}
     break;
 
   case 78:
-#line 275 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 275 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LARGEUR,
                                                     DrucIndexMesure );}
     break;
 
   case 79:
-#line 277 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 277 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_NOTCH,
                                                     DrucIndexMesure );}
     break;
 
   case 80:
-#line 279 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 279 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_SURFACE_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 81:
-#line 281 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 281 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LONGUEUR_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 82:
-#line 283 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 283 "./drucompi_y.y"
     { DrucInitRegleMesure( DRUC_MESURE_LARGEUR_INTER,
                                                     DrucIndexMesure );}
     break;
 
   case 83:
-#line 287 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 287 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_MIN,
                                                         DrucIndexMesure );}
     break;
 
   case 84:
-#line 289 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 289 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_MAX,
                                                         DrucIndexMesure );}
     break;
 
   case 85:
-#line 291 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 291 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_INFEQ,
                                                         DrucIndexMesure );}
     break;
 
   case 86:
-#line 293 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 293 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_SUPEQ,
                                                         DrucIndexMesure );}
     break;
 
   case 87:
-#line 295 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 295 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_INF,
                                                         DrucIndexMesure );}
     break;
 
   case 88:
-#line 297 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 297 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_SUP,
                                                         DrucIndexMesure );}
     break;
 
   case 89:
-#line 299 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 299 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_EQUAL,
                                                         DrucIndexMesure );}
     break;
 
   case 90:
-#line 301 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 301 "./drucompi_y.y"
     { DrucInitRegleOpCompare ( DRUC_OPERATION_DIFF,
                                                         DrucIndexMesure );}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1975 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2123 "y.tab.c"
       default: break;
     }
   VRD_Y__SYMBOL_PRINT ("-> $$ =", vrd_y_r1[vrd_y_n], &vrd_y_val, &vrd_y_loc);
@@ -1982,7 +2130,6 @@ vrd_y_reduce:
 
   *++vrd_y_vsp = vrd_y_val;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2047,7 +2194,7 @@ vrd_y_errlab:
 
   if (vrd_y_errstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (vrd_y_char <= VRD_Y_EOF)
@@ -2064,7 +2211,7 @@ vrd_y_errlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto vrd_y_errlab1;
 
@@ -2121,9 +2268,6 @@ vrd_y_errlab1:
       VRD_Y__STACK_PRINT (vrd_y_ss, vrd_y_ssp);
     }
 
-  if (vrd_y_n == VRD_Y_FINAL)
-    VRD_Y_ACCEPT;
-
   *++vrd_y_vsp = vrd_y_lval;
 
 
@@ -2148,7 +2292,7 @@ vrd_y_abortlab:
   vrd_y_result = 1;
   goto vrd_y_return;
 
-#ifndef vrd_y_overflow
+#if !defined(vrd_y_overflow) || VRD_Y_ERROR_VERBOSE
 /*-------------------------------------------------.
 | vrd_y_exhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2159,7 +2303,7 @@ vrd_y_exhaustedlab:
 #endif
 
 vrd_y_return:
-  if (vrd_y_char != VRD_Y_EOF && vrd_y_char != VRD_Y_EMPTY)
+  if (vrd_y_char != VRD_Y_EMPTY)
      vrd_y_destruct ("Cleanup: discarding lookahead",
 		 vrd_y_token, &vrd_y_lval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2185,6 +2329,8 @@ vrd_y_return:
 }
 
 
-#line 306 "../../../src/druc/src/drucompi_y.y"
+
+/* Line 1675 of yacc.c  */
+#line 306 "./drucompi_y.y"
 
 
