@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define elpYYBISON 1
 
 /* Bison version.  */
-#define elpYYBISON_VERSION "2.3"
+#define elpYYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define elpYYSKELETON_NAME "yacc.c"
@@ -55,11 +54,47 @@
 /* Pure parsers.  */
 #define elpYYPURE 0
 
+/* Push parsers.  */
+#define elpYYPUSH 0
+
+/* Pull parsers.  */
+#define elpYYPULL 1
+
 /* Using locations.  */
 #define elpYYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "./elp_y.y"
+
+#include "elp.h"
+
+
+/* Line 189 of yacc.c  */
+#line 78 "y.tab.c"
+
+/* Enabling traces.  */
+#ifndef elpYYDEBUG
+# define elpYYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef elpYYERROR_VERBOSE
+# undef elpYYERROR_VERBOSE
+# define elpYYERROR_VERBOSE 1
+#else
+# define elpYYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef elpYYTOKEN_TABLE
+# define elpYYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef elpYYTOKENTYPE
 # define elpYYTOKENTYPE
@@ -179,52 +214,32 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "../../../src/elp/src/elp_y.y"
-
-#include "elp.h"
-
-
-/* Enabling traces.  */
-#ifndef elpYYDEBUG
-# define elpYYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef elpYYERROR_VERBOSE
-# undef elpYYERROR_VERBOSE
-# define elpYYERROR_VERBOSE 1
-#else
-# define elpYYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef elpYYTOKEN_TABLE
-# define elpYYTOKEN_TABLE 0
-#endif
-
 #if ! defined elpYYSTYPE && ! defined elpYYSTYPE_IS_DECLARED
 typedef union elpYYSTYPE
-#line 5 "../../../src/elp/src/elp_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 5 "./elp_y.y"
+
        double elpdbl    ;
        char   elpstr[50];
-       }
-/* Line 187 of yacc.c.  */
-#line 215 "y.tab.c"
-	elpYYSTYPE;
+       
+
+
+/* Line 214 of yacc.c  */
+#line 231 "y.tab.c"
+} elpYYSTYPE;
+# define elpYYSTYPE_IS_TRIVIAL 1
 # define elpyystype elpYYSTYPE /* obsolescent; will be withdrawn */
 # define elpYYSTYPE_IS_DECLARED 1
-# define elpYYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 228 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 243 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -299,14 +314,14 @@ typedef short int elpyytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-elpYYID (int i)
+elpYYID (int elpyyi)
 #else
 static int
-elpYYID (i)
-    int i;
+elpYYID (elpyyi)
+    int elpyyi;
 #endif
 {
-  return i;
+  return elpyyi;
 }
 #endif
 
@@ -387,9 +402,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union elpyyalloc
 {
-  elpyytype_int16 elpyyss;
-  elpYYSTYPE elpyyvs;
-  };
+  elpyytype_int16 elpyyss_alloc;
+  elpYYSTYPE elpyyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define elpYYSTACK_GAP_MAXIMUM (sizeof (union elpyyalloc) - 1)
@@ -423,12 +438,12 @@ union elpyyalloc
    elements in the stack, and elpYYPTR gives the new location of the
    stack.  Advance elpYYPTR to a properly aligned location for the next
    stack.  */
-# define elpYYSTACK_RELOCATE(Stack)					\
+# define elpYYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	elpYYSIZE_T elpyynewbytes;						\
-	elpYYCOPY (&elpyyptr->Stack, Stack, elpyysize);				\
-	Stack = &elpyyptr->Stack;						\
+	elpYYCOPY (&elpyyptr->Stack_alloc, Stack, elpyysize);			\
+	Stack = &elpyyptr->Stack_alloc;					\
 	elpyynewbytes = elpyystacksize * sizeof (*Stack) + elpYYSTACK_GAP_MAXIMUM; \
 	elpyyptr += elpyynewbytes / sizeof (*elpyyptr);				\
       }									\
@@ -560,7 +575,7 @@ static const char *const elpyytname[] =
   "telpCSSP", "telpCSPP", "telpCSWP", "telpCGDE", "telpCGSE", "telpCGDD",
   "telpCGSD", "telpESIM", "telpMODEL", "telpLEVEL", "telpACM", "telpTEMP",
   "telpSLOPE", "telpDOUBLE", "telpSTRING", "':'", "'='", "$accept", "elp",
-  "@1", "variables", "elpvar", 0
+  "$@1", "variables", "elpvar", 0
 };
 #endif
 
@@ -907,17 +922,20 @@ elpyy_symbol_print (elpyyoutput, elpyytype, elpyyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-elpyy_stack_print (elpyytype_int16 *bottom, elpyytype_int16 *top)
+elpyy_stack_print (elpyytype_int16 *elpyybottom, elpyytype_int16 *elpyytop)
 #else
 static void
-elpyy_stack_print (bottom, top)
-    elpyytype_int16 *bottom;
-    elpyytype_int16 *top;
+elpyy_stack_print (elpyybottom, elpyytop)
+    elpyytype_int16 *elpyybottom;
+    elpyytype_int16 *elpyytop;
 #endif
 {
   elpYYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    elpYYFPRINTF (stderr, " %d", *bottom);
+  for (; elpyybottom <= elpyytop; elpyybottom++)
+    {
+      int elpyybot = *elpyybottom;
+      elpYYFPRINTF (stderr, " %d", elpyybot);
+    }
   elpYYFPRINTF (stderr, "\n");
 }
 
@@ -951,11 +969,11 @@ elpyy_reduce_print (elpyyvsp, elpyyrule)
   /* The symbols being reduced.  */
   for (elpyyi = 0; elpyyi < elpyynrhs; elpyyi++)
     {
-      fprintf (stderr, "   $%d = ", elpyyi + 1);
+      elpYYFPRINTF (stderr, "   $%d = ", elpyyi + 1);
       elpyy_symbol_print (stderr, elpyyrhs[elpyyprhs[elpyyrule] + elpyyi],
 		       &(elpyyvsp[(elpyyi + 1) - (elpyynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      elpYYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1235,10 +1253,8 @@ elpyydestruct (elpyymsg, elpyytype, elpyyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef elpYYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int elpyyparse (void *elpYYPARSE_PARAM);
@@ -1254,11 +1270,10 @@ int elpyyparse ();
 #endif /* ! elpYYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int elpyychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 elpYYSTYPE elpyylval;
 
 /* Number of syntax errors so far.  */
@@ -1266,9 +1281,9 @@ int elpyynerrs;
 
 
 
-/*----------.
-| elpyyparse.  |
-`----------*/
+/*-------------------------.
+| elpyyparse or elpyypush_parse.  |
+`-------------------------*/
 
 #ifdef elpYYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1292,14 +1307,39 @@ elpyyparse ()
 #endif
 #endif
 {
-  
-  int elpyystate;
+
+
+    int elpyystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int elpyyerrstatus;
+
+    /* The stacks and their tools:
+       `elpyyss': related to states.
+       `elpyyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow elpyyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    elpyytype_int16 elpyyssa[elpYYINITDEPTH];
+    elpyytype_int16 *elpyyss;
+    elpyytype_int16 *elpyyssp;
+
+    /* The semantic value stack.  */
+    elpYYSTYPE elpyyvsa[elpYYINITDEPTH];
+    elpYYSTYPE *elpyyvs;
+    elpYYSTYPE *elpyyvsp;
+
+    elpYYSIZE_T elpyystacksize;
+
   int elpyyn;
   int elpyyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int elpyyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int elpyytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int elpyytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  elpYYSTYPE elpyyval;
+
 #if elpYYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char elpyymsgbuf[128];
@@ -1307,51 +1347,28 @@ elpyyparse ()
   elpYYSIZE_T elpyymsg_alloc = sizeof elpyymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `elpyyss': related to states,
-     `elpyyvs': related to semantic values,
-     `elpyyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow elpyyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  elpyytype_int16 elpyyssa[elpYYINITDEPTH];
-  elpyytype_int16 *elpyyss = elpyyssa;
-  elpyytype_int16 *elpyyssp;
-
-  /* The semantic value stack.  */
-  elpYYSTYPE elpyyvsa[elpYYINITDEPTH];
-  elpYYSTYPE *elpyyvs = elpyyvsa;
-  elpYYSTYPE *elpyyvsp;
-
-
-
 #define elpYYPOPSTACK(N)   (elpyyvsp -= (N), elpyyssp -= (N))
 
-  elpYYSIZE_T elpyystacksize = elpYYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  elpYYSTYPE elpyyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int elpyylen = 0;
 
+  elpyytoken = 0;
+  elpyyss = elpyyssa;
+  elpyyvs = elpyyvsa;
+  elpyystacksize = elpYYINITDEPTH;
+
   elpYYDPRINTF ((stderr, "Starting parse\n"));
 
   elpyystate = 0;
   elpyyerrstatus = 0;
   elpyynerrs = 0;
-  elpyychar = elpYYEMPTY;		/* Cause a token to be read.  */
+  elpyychar = elpYYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   elpyyssp = elpyyss;
   elpyyvsp = elpyyvs;
 
@@ -1381,7 +1398,6 @@ elpyyparse ()
 	elpYYSTYPE *elpyyvs1 = elpyyvs;
 	elpyytype_int16 *elpyyss1 = elpyyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1389,7 +1405,6 @@ elpyyparse ()
 	elpyyoverflow (elpYY_("memory exhausted"),
 		    &elpyyss1, elpyysize * sizeof (*elpyyssp),
 		    &elpyyvs1, elpyysize * sizeof (*elpyyvsp),
-
 		    &elpyystacksize);
 
 	elpyyss = elpyyss1;
@@ -1412,9 +1427,8 @@ elpyyparse ()
 	  (union elpyyalloc *) elpYYSTACK_ALLOC (elpYYSTACK_BYTES (elpyystacksize));
 	if (! elpyyptr)
 	  goto elpyyexhaustedlab;
-	elpYYSTACK_RELOCATE (elpyyss);
-	elpYYSTACK_RELOCATE (elpyyvs);
-
+	elpYYSTACK_RELOCATE (elpyyss_alloc, elpyyss);
+	elpYYSTACK_RELOCATE (elpyyvs_alloc, elpyyvs);
 #  undef elpYYSTACK_RELOCATE
 	if (elpyyss1 != elpyyssa)
 	  elpYYSTACK_FREE (elpyyss1);
@@ -1425,7 +1439,6 @@ elpyyparse ()
       elpyyssp = elpyyss + elpyysize - 1;
       elpyyvsp = elpyyvs + elpyysize - 1;
 
-
       elpYYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) elpyystacksize));
 
@@ -1435,6 +1448,9 @@ elpyyparse ()
 
   elpYYDPRINTF ((stderr, "Entering state %d\n", elpyystate));
 
+  if (elpyystate == elpYYFINAL)
+    elpYYACCEPT;
+
   goto elpyybackup;
 
 /*-----------.
@@ -1443,16 +1459,16 @@ elpyyparse ()
 elpyybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   elpyyn = elpyypact[elpyystate];
   if (elpyyn == elpYYPACT_NINF)
     goto elpyydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* elpYYCHAR is either elpYYEMPTY or elpYYEOF or a valid look-ahead symbol.  */
+  /* elpYYCHAR is either elpYYEMPTY or elpYYEOF or a valid lookahead symbol.  */
   if (elpyychar == elpYYEMPTY)
     {
       elpYYDPRINTF ((stderr, "Reading a token: "));
@@ -1484,20 +1500,16 @@ elpyybackup:
       goto elpyyreduce;
     }
 
-  if (elpyyn == elpYYFINAL)
-    elpYYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (elpyyerrstatus)
     elpyyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   elpYY_SYMBOL_PRINT ("Shifting", elpyytoken, &elpyylval, &elpyylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (elpyychar != elpYYEOF)
-    elpyychar = elpYYEMPTY;
+  /* Discard the shifted token.  */
+  elpyychar = elpYYEMPTY;
 
   elpyystate = elpyyn;
   *++elpyyvsp = elpyylval;
@@ -1537,7 +1549,9 @@ elpyyreduce:
   switch (elpyyn)
     {
         case 2:
-#line 26 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 26 "./elp_y.y"
     {
                 strcpy(elpTechnoName,(elpyyvsp[(3) - (6)].elpstr)) ;
                 elpTechnoVersion = (elpyyvsp[(6) - (6)].elpdbl) ;
@@ -1545,248 +1559,345 @@ elpyyreduce:
     break;
 
   case 6:
-#line 39 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 39 "./elp_y.y"
     {elpShrink[elpLMLT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 7:
-#line 40 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 40 "./elp_y.y"
     {elpShrink[elpWMLT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 8:
-#line 41 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 41 "./elp_y.y"
     {elpShrink[elpDLN]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 9:
-#line 42 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 42 "./elp_y.y"
     {elpShrink[elpDWN]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 10:
-#line 43 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 43 "./elp_y.y"
     {elpShrink[elpDLP]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 11:
-#line 44 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 44 "./elp_y.y"
     {elpShrink[elpDWP]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 12:
-#line 45 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 45 "./elp_y.y"
     {elpShrink[elpDLE]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 13:
-#line 46 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 46 "./elp_y.y"
     {elpShrink[elpDWE]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 14:
-#line 47 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 47 "./elp_y.y"
     {elpShrink[elpDLD]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 15:
-#line 48 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 48 "./elp_y.y"
     {elpShrink[elpDWD]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 16:
-#line 51 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 51 "./elp_y.y"
     {elpModel[elpNMOS][elpVT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 17:
-#line 52 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 52 "./elp_y.y"
     {elpModel[elpNMOS][elpA]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 18:
-#line 53 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 53 "./elp_y.y"
     {elpModel[elpNMOS][elpB]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 19:
-#line 54 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 54 "./elp_y.y"
     {elpModel[elpNMOS][elpRT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 20:
-#line 55 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 55 "./elp_y.y"
     {elpModel[elpPMOS][elpVT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 21:
-#line 56 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 56 "./elp_y.y"
     {elpModel[elpPMOS][elpA]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 22:
-#line 57 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 57 "./elp_y.y"
     {elpModel[elpPMOS][elpB]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 23:
-#line 58 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 58 "./elp_y.y"
     {elpModel[elpPMOS][elpRT] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 24:
-#line 61 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 61 "./elp_y.y"
     {elpVoltage[elpVDDMAX] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 25:
-#line 62 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 62 "./elp_y.y"
     {elpVoltage[elpVDDDEG] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 26:
-#line 63 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 63 "./elp_y.y"
     {elpVoltage[elpVSSDEG] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 27:
-#line 64 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 64 "./elp_y.y"
     {elpVoltage[elpVTHR]   = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 28:
-#line 67 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 67 "./elp_y.y"
     {elpCapa[elpNMOS][elpCGS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 29:
-#line 68 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 68 "./elp_y.y"
     {elpCapa[elpNMOS][elpCGP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 30:
-#line 69 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 69 "./elp_y.y"
     {elpCapa[elpPMOS][elpCGS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 31:
-#line 70 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 70 "./elp_y.y"
     {elpCapa[elpPMOS][elpCGP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 32:
-#line 71 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 71 "./elp_y.y"
     {elpCapa[elpNMOS][elpCDS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 33:
-#line 72 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 72 "./elp_y.y"
     {elpCapa[elpNMOS][elpCDP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 34:
-#line 73 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 73 "./elp_y.y"
     {elpCapa[elpNMOS][elpCDW] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 35:
-#line 74 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 74 "./elp_y.y"
     {elpCapa[elpPMOS][elpCDS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 36:
-#line 75 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 75 "./elp_y.y"
     {elpCapa[elpPMOS][elpCDP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 37:
-#line 76 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 76 "./elp_y.y"
     {elpCapa[elpPMOS][elpCDW] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 38:
-#line 77 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 77 "./elp_y.y"
     {elpCapa[elpNMOS][elpCSS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 39:
-#line 78 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 78 "./elp_y.y"
     {elpCapa[elpNMOS][elpCSP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 40:
-#line 79 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 79 "./elp_y.y"
     {elpCapa[elpNMOS][elpCSW] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 41:
-#line 80 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 80 "./elp_y.y"
     {elpCapa[elpPMOS][elpCSS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 42:
-#line 81 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 81 "./elp_y.y"
     {elpCapa[elpPMOS][elpCSP] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 43:
-#line 82 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 82 "./elp_y.y"
     {elpCapa[elpPMOS][elpCSW] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 44:
-#line 83 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 83 "./elp_y.y"
     {elpCapa[elpEMES][elpCSGD] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 45:
-#line 84 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 84 "./elp_y.y"
     {elpCapa[elpDMES][elpCSGS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 46:
-#line 85 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 85 "./elp_y.y"
     {elpCapa[elpDMES][elpCSGD] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 47:
-#line 86 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 86 "./elp_y.y"
     {elpCapa[elpEMES][elpCSGS] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 48:
-#line 89 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 89 "./elp_y.y"
     {strcpy(elpEsimName,(elpyyvsp[(3) - (3)].elpstr))       ;}
     break;
 
   case 49:
-#line 90 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 90 "./elp_y.y"
     {strcpy(elpModelName,(elpyyvsp[(3) - (3)].elpstr))      ;}
     break;
 
   case 50:
-#line 91 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 91 "./elp_y.y"
     {elpEsimLevel = (elpyyvsp[(3) - (3)].elpdbl)            ;}
     break;
 
   case 51:
-#line 94 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 94 "./elp_y.y"
     {elpGeneral[elpACM]   = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 52:
-#line 95 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 95 "./elp_y.y"
     {elpGeneral[elpTEMP]  = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
   case 53:
-#line 96 "../../../src/elp/src/elp_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 96 "./elp_y.y"
     {elpGeneral[elpSLOPE] = (elpyyvsp[(3) - (3)].elpdbl) ;}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1790 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1901 "y.tab.c"
       default: break;
     }
   elpYY_SYMBOL_PRINT ("-> $$ =", elpyyr1[elpyyn], &elpyyval, &elpyyloc);
@@ -1797,7 +1908,6 @@ elpyyreduce:
 
   *++elpyyvsp = elpyyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1862,7 +1972,7 @@ elpyyerrlab:
 
   if (elpyyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (elpyychar <= elpYYEOF)
@@ -1879,7 +1989,7 @@ elpyyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto elpyyerrlab1;
 
@@ -1936,9 +2046,6 @@ elpyyerrlab1:
       elpYY_STACK_PRINT (elpyyss, elpyyssp);
     }
 
-  if (elpyyn == elpYYFINAL)
-    elpYYACCEPT;
-
   *++elpyyvsp = elpyylval;
 
 
@@ -1963,7 +2070,7 @@ elpyyabortlab:
   elpyyresult = 1;
   goto elpyyreturn;
 
-#ifndef elpyyoverflow
+#if !defined(elpyyoverflow) || elpYYERROR_VERBOSE
 /*-------------------------------------------------.
 | elpyyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1974,7 +2081,7 @@ elpyyexhaustedlab:
 #endif
 
 elpyyreturn:
-  if (elpyychar != elpYYEOF && elpyychar != elpYYEMPTY)
+  if (elpyychar != elpYYEMPTY)
      elpyydestruct ("Cleanup: discarding lookahead",
 		 elpyytoken, &elpyylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2000,7 +2107,9 @@ elpyyreturn:
 }
 
 
-#line 98 "../../../src/elp/src/elp_y.y"
+
+/* Line 1675 of yacc.c  */
+#line 98 "./elp_y.y"
 
 
 extern int  elpyylineno ;
