@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,56 +54,21 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     IF = 258,
-     PP = 259,
-     MM = 260,
-     MAX = 261,
-     MIN = 262,
-     SUP = 263,
-     INF = 264,
-     SORT = 265,
-     RSORT = 266,
-     MESS = 267,
-     DEF = 268,
-     NDEF = 269,
-     NUMBER = 270,
-     IDENT = 271,
-     REGEX = 272
-   };
-#endif
-/* Tokens.  */
-#define IF 258
-#define PP 259
-#define MM 260
-#define MAX 261
-#define MIN 262
-#define SUP 263
-#define INF 264
-#define SORT 265
-#define RSORT 266
-#define MESS 267
-#define DEF 268
-#define NDEF 269
-#define NUMBER 270
-#define IDENT 271
-#define REGEX 272
-
-
-
-
 /* Copy the first part of user declarations.  */
-#line 1 "../../../src/exp/src/expy.y"
+
+/* Line 189 of yacc.c  */
+#line 1 "expy.y"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -200,6 +164,9 @@ htelt_t *mess (int type, char *fmt, htelt_t * args)
 
 
 
+/* Line 189 of yacc.c  */
+#line 169 "expy.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -218,28 +185,76 @@ htelt_t *mess (int type, char *fmt, htelt_t * args)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     IF = 258,
+     PP = 259,
+     MM = 260,
+     MAX = 261,
+     MIN = 262,
+     SUP = 263,
+     INF = 264,
+     SORT = 265,
+     RSORT = 266,
+     MESS = 267,
+     DEF = 268,
+     NDEF = 269,
+     NUMBER = 270,
+     IDENT = 271,
+     REGEX = 272
+   };
+#endif
+/* Tokens.  */
+#define IF 258
+#define PP 259
+#define MM 260
+#define MAX 261
+#define MIN 262
+#define SUP 263
+#define INF 264
+#define SORT 265
+#define RSORT 266
+#define MESS 267
+#define DEF 268
+#define NDEF 269
+#define NUMBER 270
+#define IDENT 271
+#define REGEX 272
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 96 "../../../src/exp/src/expy.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 96 "expy.y"
+
   htelt_t * e;
   double    f;
-}
-/* Line 187 of yacc.c.  */
-#line 230 "expy.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 246 "expy.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 243 "expy.c"
+/* Line 264 of yacc.c  */
+#line 258 "expy.c"
 
 #ifdef short
 # undef short
@@ -314,14 +329,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -402,9 +417,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -438,12 +453,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -916,17 +931,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -960,11 +978,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1244,10 +1262,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1263,11 +1279,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1275,9 +1290,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1301,14 +1316,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1316,51 +1356,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1390,7 +1407,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1398,7 +1414,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1421,9 +1436,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1434,7 +1448,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1444,6 +1457,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1452,16 +1468,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1493,20 +1509,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1546,82 +1558,114 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 110 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 110 "expy.y"
     { if (VERBOSE>1) htstat(dico); return 1;}
     break;
 
   case 4:
-#line 113 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 113 "expy.y"
     { fprintf (yyout, float_fmt, (yyvsp[(3) - (4)].f));}
     break;
 
   case 5:
-#line 114 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 114 "expy.y"
     { fprintf (yyout, integer_fmt, (int)(yyvsp[(3) - (4)].f));}
     break;
 
   case 6:
-#line 115 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 115 "expy.y"
     { fprintf (yyout, float_fmt, (yyvsp[(2) - (3)].f));}
     break;
 
   case 7:
-#line 116 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 116 "expy.y"
     { fprintf (yyout, integer_fmt, (int)(yyvsp[(2) - (3)].f));}
     break;
 
   case 8:
-#line 117 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 117 "expy.y"
     { mess(SORT,float_fmt, bsort (SORT, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 9:
-#line 118 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 118 "expy.y"
     { mess(SORT,integer_fmt, bsort (SORT, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 10:
-#line 119 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 119 "expy.y"
     { mess(SORT,float_fmt, bsort (RSORT, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 11:
-#line 120 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 120 "expy.y"
     { mess(SORT,integer_fmt, bsort (RSORT, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 12:
-#line 121 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 121 "expy.y"
     { mess(MESS,float_fmt, bsort (MESS, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 13:
-#line 122 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 122 "expy.y"
     { mess(MESS,integer_fmt, bsort (MESS, (yyvsp[(4) - (6)].e)));}
     break;
 
   case 14:
-#line 123 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 123 "expy.y"
     { }
     break;
 
   case 15:
-#line 124 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 124 "expy.y"
     { }
     break;
 
   case 16:
-#line 126 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 126 "expy.y"
     { }
     break;
 
   case 17:
-#line 127 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 127 "expy.y"
     { }
     break;
 
   case 18:
-#line 129 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 129 "expy.y"
     { if ((pcond==0) || (cond[pcond]>0.)) {
                                           (yyvsp[(1) - (3)].e)->VAL.f=(yyvsp[(3) - (3)].f); (yyvsp[(1) - (3)].e)->TYPE=HT_FLOAT; 
                                           (yyvsp[(1) - (3)].e)->FNAME=expfname; (yyvsp[(1) - (3)].e)->FLINE=lineno; 
@@ -1631,67 +1675,93 @@ yyreduce:
     break;
 
   case 19:
-#line 135 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 135 "expy.y"
     { (yyval.f) = (yyvsp[(1) - (1)].f);  pe(" ",(yyval.f));}
     break;
 
   case 20:
-#line 136 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 136 "expy.y"
     { test_init((yyvsp[(1) - (1)].e)); (yyval.f) = (yyvsp[(1) - (1)].e)->VAL.f; pi((yyvsp[(1) - (1)].e));}
     break;
 
   case 21:
-#line 137 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 137 "expy.y"
     { test_init((yyvsp[(1) - (2)].e)); (yyval.f) = (yyvsp[(1) - (2)].e)->VAL.f; (yyvsp[(1) - (2)].e)->VAL.f += 1.0;}
     break;
 
   case 22:
-#line 138 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 138 "expy.y"
     { test_init((yyvsp[(1) - (2)].e)); (yyval.f) = (yyvsp[(1) - (2)].e)->VAL.f; (yyvsp[(1) - (2)].e)->VAL.f -= 1.0;}
     break;
 
   case 23:
-#line 139 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 139 "expy.y"
     { (yyval.f) = ((yyvsp[(1) - (3)].f) < (yyvsp[(3) - (3)].f)) ? 1. : -1.; pe(" < ",(yyval.f));}
     break;
 
   case 24:
-#line 140 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 140 "expy.y"
     { (yyval.f) = ((yyvsp[(1) - (3)].f) > (yyvsp[(3) - (3)].f)) ? 1. : -1.; pe(" > ",(yyval.f));}
     break;
 
   case 25:
-#line 141 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 141 "expy.y"
     { (yyval.f) = (yyvsp[(1) - (3)].f) + (yyvsp[(3) - (3)].f); pe(" + ",(yyval.f));}
     break;
 
   case 26:
-#line 142 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 142 "expy.y"
     { (yyval.f) = (yyvsp[(1) - (3)].f) - (yyvsp[(3) - (3)].f); pe(" - ",(yyval.f));}
     break;
 
   case 27:
-#line 143 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 143 "expy.y"
     { (yyval.f) = (yyvsp[(1) - (3)].f) * (yyvsp[(3) - (3)].f); pe(" * ",(yyval.f));}
     break;
 
   case 28:
-#line 144 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 144 "expy.y"
     { (yyval.f) = (yyvsp[(1) - (3)].f) / (yyvsp[(3) - (3)].f); pe(" / ",(yyval.f));}
     break;
 
   case 29:
-#line 145 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 145 "expy.y"
     { (yyval.f) = (yyvsp[(2) - (3)].f);}
     break;
 
   case 30:
-#line 146 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 146 "expy.y"
     { (yyval.f) = -(yyvsp[(2) - (2)].f); pe(" - ",(yyval.f));}
     break;
 
   case 31:
-#line 147 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 147 "expy.y"
     { for (ele = (yyvsp[(5) - (6)].e); ele->NEXT; ele = ele->NEXT);
                                         (yyval.f) = ele->VAL.f;
                                         pcond--; eltremove ((yyvsp[(5) - (6)].e)); 
@@ -1699,37 +1769,51 @@ yyreduce:
     break;
 
   case 32:
-#line 151 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 151 "expy.y"
     { (yyval.f) = anint(((yyvsp[(5) - (6)].f)+((yyvsp[(3) - (6)].f)/2)-EPSILON)/(yyvsp[(3) - (6)].f))*(yyvsp[(3) - (6)].f); pe(" sup ",(yyval.f));}
     break;
 
   case 33:
-#line 152 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 152 "expy.y"
     { (yyval.f) = ((int)(floor(((yyvsp[(5) - (6)].f)+EPSILON)/(yyvsp[(3) - (6)].f))))*(yyvsp[(3) - (6)].f); pe(" inf ",(yyval.f));}
     break;
 
   case 34:
-#line 153 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 153 "expy.y"
     { (yyval.f) = limit (MAX, (yyvsp[(3) - (4)].e)); pe(" max ",(yyval.f));}
     break;
 
   case 35:
-#line 154 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 154 "expy.y"
     { (yyval.f) = limit (MIN, (yyvsp[(3) - (4)].e)); pe(" min ",(yyval.f));}
     break;
 
   case 36:
-#line 155 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 155 "expy.y"
     { (yyval.f) = ((yyvsp[(3) - (4)].e)->TYPE==0) ? -1. : +1.; pe((yyvsp[(3) - (4)].e),(yyval.f));}
     break;
 
   case 37:
-#line 156 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 156 "expy.y"
     { (yyval.f) = ((yyvsp[(3) - (4)].e)->TYPE==0) ? +1. : -1.; pe((yyvsp[(3) - (4)].e),(yyval.f));}
     break;
 
   case 38:
-#line 158 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 158 "expy.y"
     { if (pcond < PCONDMAX) 
                                           cond[++pcond] = (yyvsp[(1) - (1)].f); 
                                         else
@@ -1738,37 +1822,51 @@ yyreduce:
     break;
 
   case 39:
-#line 164 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 164 "expy.y"
     { (yyval.e) = eltadd (NULL,NULL); (yyval.e)->VAL.e=(yyvsp[(1) - (1)].e);}
     break;
 
   case 40:
-#line 165 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 165 "expy.y"
     { (yyval.e) = eltadd ((yyvsp[(3) - (3)].e),NULL); (yyval.e)->VAL.e=(yyvsp[(1) - (3)].e);}
     break;
 
   case 41:
-#line 166 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 166 "expy.y"
     { (yyval.e) = (yyvsp[(1) - (1)].e)->NEXT; (yyvsp[(1) - (1)].e)->NEXT=NULL;}
     break;
 
   case 42:
-#line 167 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 167 "expy.y"
     { (yyval.e) = (yyvsp[(1) - (3)].e)->NEXT; (yyvsp[(1) - (3)].e)->NEXT=(yyvsp[(3) - (3)].e);}
     break;
 
   case 43:
-#line 169 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 169 "expy.y"
     { (yyval.e) = eltadd (NULL,NULL); (yyval.e)->VAL.f=(yyvsp[(1) - (1)].f); (yyval.e)->TYPE=HT_FLOAT;pe(" , ",(yyvsp[(1) - (1)].f));}
     break;
 
   case 44:
-#line 170 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 170 "expy.y"
     { (yyval.e) = eltadd ((yyvsp[(3) - (3)].e),NULL); (yyval.e)->VAL.f=(yyvsp[(1) - (3)].f); (yyval.e)->TYPE=HT_FLOAT;pe(" , ",(yyvsp[(3) - (3)].e));}
     break;
 
   case 45:
-#line 171 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 171 "expy.y"
     { (yyval.e) = (yyvsp[(1) - (1)].e)->NEXT; (yyvsp[(1) - (1)].e)->NEXT=NULL; 
                                         for (ele = (yyval.e); ele; ele = ele->NEXT)
                                         {  
@@ -1780,7 +1878,9 @@ yyreduce:
     break;
 
   case 46:
-#line 179 "../../../src/exp/src/expy.y"
+
+/* Line 1455 of yacc.c  */
+#line 179 "expy.y"
     { (yyval.e) = (yyvsp[(1) - (3)].e)->NEXT; (yyvsp[(1) - (3)].e)->NEXT=(yyvsp[(3) - (3)].e);   
                                         for (ele = (yyvsp[(1) - (3)].e); ele; ele = ele->NEXT)
                                         {
@@ -1792,8 +1892,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1797 "expy.c"
+
+/* Line 1455 of yacc.c  */
+#line 1898 "expy.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1804,7 +1905,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1869,7 +1969,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1886,7 +1986,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1943,9 +2043,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1970,7 +2067,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1981,7 +2078,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2007,7 +2104,9 @@ yyreturn:
 }
 
 
-#line 188 "../../../src/exp/src/expy.y"
+
+/* Line 1675 of yacc.c  */
+#line 188 "expy.y"
 
 int yyerror(char *s)
 {
