@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,44 +54,21 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     CONSTANT = 258,
-     OTHERS = 259,
-     WHEN = 260,
-     SELECT = 261,
-     WITH = 262,
-     STRING = 263,
-     BSTRING = 264,
-     OSTRING = 265,
-     XSTRING = 266
-   };
-#endif
-/* Tokens.  */
-#define CONSTANT 258
-#define OTHERS 259
-#define WHEN 260
-#define SELECT 261
-#define WITH 262
-#define STRING 263
-#define BSTRING 264
-#define OSTRING 265
-#define XSTRING 266
-
-
-
-
 /* Copy the first part of user declarations.  */
-#line 7 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 189 of yacc.c  */
+#line 7 "dpgen_ROM_code.y"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -225,6 +201,9 @@ char *s;
 
 
 
+/* Line 189 of yacc.c  */
+#line 206 "dpgen_ROM_code.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -243,28 +222,64 @@ char *s;
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     CONSTANT = 258,
+     OTHERS = 259,
+     WHEN = 260,
+     SELECT = 261,
+     WITH = 262,
+     STRING = 263,
+     BSTRING = 264,
+     OSTRING = 265,
+     XSTRING = 266
+   };
+#endif
+/* Tokens.  */
+#define CONSTANT 258
+#define OTHERS 259
+#define WHEN 260
+#define SELECT 261
+#define WITH 262
+#define STRING 263
+#define BSTRING 264
+#define OSTRING 265
+#define XSTRING 266
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 139 "../../../src/genlib/src/dpgen_ROM_code.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 139 "dpgen_ROM_code.y"
+
 	int integer;
 	char string[256];
-}
-/* Line 187 of yacc.c.  */
-#line 255 "dpgen_ROM_code.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 271 "dpgen_ROM_code.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 268 "dpgen_ROM_code.c"
+/* Line 264 of yacc.c  */
+#line 283 "dpgen_ROM_code.c"
 
 #ifdef short
 # undef short
@@ -339,14 +354,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -427,9 +442,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -463,12 +478,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -570,7 +585,7 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "CONSTANT", "OTHERS", "WHEN", "SELECT",
   "WITH", "STRING", "BSTRING", "OSTRING", "XSTRING", "'('", "')'", "'<'",
   "'='", "','", "';'", "'&'", "$accept", "line", "constant", "value",
-  "dvalues", "@1", "@2", "avalues", "@3", "@4", 0
+  "dvalues", "$@1", "$@2", "avalues", "$@3", "$@4", 0
 };
 #endif
 
@@ -859,17 +874,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -903,11 +921,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1187,10 +1205,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1206,11 +1222,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1218,9 +1233,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1244,14 +1259,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1259,51 +1299,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1333,7 +1350,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1341,7 +1357,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1364,9 +1379,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1377,7 +1391,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1387,6 +1400,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1395,16 +1411,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1436,20 +1452,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1489,7 +1501,9 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 154 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 154 "dpgen_ROM_code.y"
     {
 				if (atoi((yyvsp[(4) - (8)].string)) != 0 && atoi((yyvsp[(6) - (8)].string)) != 0)
 					yyerror("illegal vector boundaries for GRoG");
@@ -1505,7 +1519,9 @@ yyreduce:
     break;
 
   case 5:
-#line 167 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 167 "dpgen_ROM_code.y"
     {
 			int i;
 #ifdef PARSEOUT
@@ -1549,7 +1565,9 @@ yyreduce:
     break;
 
   case 6:
-#line 208 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 208 "dpgen_ROM_code.y"
     {
 			int i;
 #ifdef PARSEOUT
@@ -1581,7 +1599,9 @@ yyreduce:
     break;
 
   case 7:
-#line 237 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 237 "dpgen_ROM_code.y"
     {
 			int i;
 #ifdef PARSEOUT
@@ -1613,7 +1633,9 @@ yyreduce:
     break;
 
   case 8:
-#line 266 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 266 "dpgen_ROM_code.y"
     {
 			int  i;
          	long j[2];
@@ -1642,44 +1664,60 @@ yyreduce:
     break;
 
   case 9:
-#line 291 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 291 "dpgen_ROM_code.y"
     {strcpy((yyval.string), "Just to have bison shut up");}
     break;
 
   case 10:
-#line 295 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 295 "dpgen_ROM_code.y"
     {
 				asc = adddptr(asc, (yyvsp[(2) - (5)].string), (yyvsp[(4) - (5)].string));
 			}
     break;
 
   case 11:
-#line 300 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 300 "dpgen_ROM_code.y"
     {strcpy((yyval.string), (yyvsp[(1) - (1)].string));}
     break;
 
   case 12:
-#line 301 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 301 "dpgen_ROM_code.y"
     {strcpy((yyval.string), octbin((yyvsp[(1) - (1)].string)));}
     break;
 
   case 13:
-#line 302 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 302 "dpgen_ROM_code.y"
     {strcpy((yyval.string), hexbin((yyvsp[(1) - (1)].string)));}
     break;
 
   case 14:
-#line 305 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 305 "dpgen_ROM_code.y"
     {strcat(datbuf, (yyvsp[(1) - (1)].string));}
     break;
 
   case 15:
-#line 306 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 306 "dpgen_ROM_code.y"
     {strcat(datbuf, (yyvsp[(1) - (1)].string));}
     break;
 
   case 17:
-#line 308 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 308 "dpgen_ROM_code.y"
     {
 			char *p = getdptr(asc, (yyvsp[(1) - (1)].string));
 
@@ -1692,7 +1730,9 @@ yyreduce:
     break;
 
   case 18:
-#line 317 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 317 "dpgen_ROM_code.y"
     {
 			char *p = getdptr(asc, (yyvsp[(1) - (1)].string));
 
@@ -1705,17 +1745,23 @@ yyreduce:
     break;
 
   case 20:
-#line 328 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 328 "dpgen_ROM_code.y"
     {strcat(adrbuf, (yyvsp[(1) - (1)].string));}
     break;
 
   case 21:
-#line 329 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 329 "dpgen_ROM_code.y"
     {strcat(adrbuf, (yyvsp[(1) - (1)].string));}
     break;
 
   case 23:
-#line 331 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 331 "dpgen_ROM_code.y"
     {
 			char *p = getdptr(asc, (yyvsp[(1) - (1)].string));
 
@@ -1728,7 +1774,9 @@ yyreduce:
     break;
 
   case 24:
-#line 340 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1455 of yacc.c  */
+#line 340 "dpgen_ROM_code.y"
     {
 			char *p = getdptr(asc, (yyvsp[(1) - (1)].string));
 
@@ -1741,8 +1789,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1746 "dpgen_ROM_code.c"
+
+/* Line 1455 of yacc.c  */
+#line 1795 "dpgen_ROM_code.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1753,7 +1802,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1818,7 +1866,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1835,7 +1883,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1892,9 +1940,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1919,7 +1964,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1930,7 +1975,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1956,7 +2001,9 @@ yyreturn:
 }
 
 
-#line 351 "../../../src/genlib/src/dpgen_ROM_code.y"
+
+/* Line 1675 of yacc.c  */
+#line 351 "dpgen_ROM_code.y"
 
 
 void dpgen_ROM_code(s, nb, nw, r, msb, data)
