@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /***************************************************************/
@@ -27,7 +27,7 @@
 /* auteurs  : RENAUD & VENOT & PITON                           */
 /***************************************************************/
 
-#ident "$Id: ARRAY.c,v 1.3 2003/09/11 13:07:05 fred Exp $"
+#ident "$Id: ARRAY.c,v 1.4 2012/05/14 14:20:14 alliance Exp $"
 
 #include <stdlib.h>
 #include <stdio.h>
