@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /****************************************************************************/
@@ -46,7 +46,7 @@
 /* printer.                                                                 */
 /****************************************************************************/
 
-#ident "$Id: drive_ps.c,v 1.5 2005/02/17 15:34:44 jpc Exp $"
+#ident "$Id: drive_ps.c,v 1.6 2012/05/14 14:20:19 alliance Exp $"
 
 #define DRIVE2PS
 
