@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /****************************************************************************/
@@ -39,7 +39,7 @@
 /*                                                                          */
 /****************************************************************************/
 
-#ident "$Id: l2p.c,v 1.4 2002/09/30 16:20:42 czo Exp $"
+#ident "$Id: l2p.c,v 1.5 2012/05/14 14:20:19 alliance Exp $"
 
 #include <stdio.h>
 #include <stdlib.h>
