@@ -18,7 +18,7 @@
  *
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -31,7 +31,7 @@
 
 
 
-#ident "$Id: log_bdd1.c,v 1.3 2009/06/14 13:51:47 ludo Exp $"
+#ident "$Id: log_bdd1.c,v 1.4 2012/05/14 14:20:19 alliance Exp $"
 
 
 /****************************************************************************/
