@@ -18,7 +18,7 @@
  *
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -30,7 +30,7 @@
 
 
 
-#ident "$Id: log_thashbdd.c,v 1.4 2009/06/14 13:51:47 ludo Exp $"
+#ident "$Id: log_thashbdd.c,v 1.5 2012/05/14 14:20:20 alliance Exp $"
 
 /*--------------------------------------------------------------------------
    la table de hachage des BDD 
