@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ident "@(#)Gate Netlist Comparator"
@@ -41,6 +41,9 @@
 /*                                                                          */
 /****************************************************************************/
 /* $Log: lvx.c,v $
+/* Revision 1.5  2012/05/14 14:20:21  alliance
+/* Updated GNU/FSF address (patch from Thibault North).
+/*
 /* Revision 1.4  2004/05/22 14:26:08  ludo
 /* Now, by default LVX does not check unassigned signals between the two input netlists.
 /* (this feature is usefull/mandatory with the new VST driver that adds sometimes unused
@@ -95,7 +98,7 @@
  *
  */
 
-static char rcsid[] = "$Id: lvx.c,v 1.4 2004/05/22 14:26:08 ludo Exp $" ;
+static char rcsid[] = "$Id: lvx.c,v 1.5 2012/05/14 14:20:21 alliance Exp $" ;
 
 #include <stdio.h>
 #include <string.h>
