@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define MGNBISON 1
 
 /* Bison version.  */
-#define MGNBISON_VERSION "2.3"
+#define MGNBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define MGNSKELETON_NAME "yacc.c"
@@ -55,11 +54,90 @@
 /* Pure parsers.  */
 #define MGNPURE 0
 
+/* Push parsers.  */
+#define MGNPUSH 0
+
+/* Pull parsers.  */
+#define MGNPULL 1
+
 /* Using locations.  */
 #define MGNLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 30 "./mg2mbk_y.y"
+
+#include <stdio.h>
+#include <string.h>
+#include <mut.h>
+#include <mph.h>
+#define MAXLAYER (LAST_LAYER + 1)
+
+static phfig_list *mgleaf; /* modgen leaf cell parsed */
+static char mbk_layer();
+static char *checkinsname();
+static char *checkconname();
+static char *checkrefname();
+static chain_list *pl;
+static int Extension[MAXLAYER] = {
+	/*	NWELL	 */ 0,
+	/*	PWELL	 */ 0,
+	/*	NTIE	 */ 1,
+	/*	PTIE	 */ 1,
+	/*	NDIF	 */ 1,
+	/*	PDIF	 */ 1,
+	/*	NTRANS */ 0, /* meant for N transistor grid */
+	/*	PTRANS */ 0, /* meant for P transistor grid */
+	/*	POLY	 */ 1,
+	/*	ALU1	 */ 1,
+	/*	ALU2	 */ 2,
+	/*	ALU3	 */ 2,
+	/*	TPOLY	 */ 1,
+	/*	TALU1	 */ 1,
+	/*	TALU2	 */ 2,
+	/*	TALU3	 */ 2 };
+
+#define O_PS_AA 1.5
+#define O_AA_PS 2
+
+#ifdef GRIDDED
+#define TWO 2
+#else
+#define TWO 1
+#endif
+
+/* note :
+   All STRINGs are allocated using mbkstrdup since the pointer to mgntext
+   will change when more than a STRING is used in the grammar.
+   So all STRINGs are freed once used. */
+
+
+
+/* Line 189 of yacc.c  */
+#line 121 "y.tab.c"
+
+/* Enabling traces.  */
+#ifndef MGNDEBUG
+# define MGNDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef MGNERROR_VERBOSE
+# undef MGNERROR_VERBOSE
+# define MGNERROR_VERBOSE 1
+#else
+# define MGNERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef MGNTOKEN_TABLE
+# define MGNTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef MGNTOKENTYPE
 # define MGNTOKENTYPE
@@ -131,99 +209,36 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 30 "../../../src/mbkmg/src/mg2mbk_y.y"
-
-#include <stdio.h>
-#include <string.h>
-#include <mut.h>
-#include <mph.h>
-#define MAXLAYER (LAST_LAYER + 1)
-
-static phfig_list *mgleaf; /* modgen leaf cell parsed */
-static char mbk_layer();
-static char *checkinsname();
-static char *checkconname();
-static char *checkrefname();
-static chain_list *pl;
-static int Extension[MAXLAYER] = {
-	/*	NWELL	 */ 0,
-	/*	PWELL	 */ 0,
-	/*	NTIE	 */ 1,
-	/*	PTIE	 */ 1,
-	/*	NDIF	 */ 1,
-	/*	PDIF	 */ 1,
-	/*	NTRANS */ 0, /* meant for N transistor grid */
-	/*	PTRANS */ 0, /* meant for P transistor grid */
-	/*	POLY	 */ 1,
-	/*	ALU1	 */ 1,
-	/*	ALU2	 */ 2,
-	/*	ALU3	 */ 2,
-	/*	TPOLY	 */ 1,
-	/*	TALU1	 */ 1,
-	/*	TALU2	 */ 2,
-	/*	TALU3	 */ 2 };
-
-#define O_PS_AA 1.5
-#define O_AA_PS 2
-
-#ifdef GRIDDED
-#define TWO 2
-#else
-#define TWO 1
-#endif
-
-/* note :
-   All STRINGs are allocated using mbkstrdup since the pointer to mgntext
-   will change when more than a STRING is used in the grammar.
-   So all STRINGs are freed once used. */
-
-
-
-/* Enabling traces.  */
-#ifndef MGNDEBUG
-# define MGNDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef MGNERROR_VERBOSE
-# undef MGNERROR_VERBOSE
-# define MGNERROR_VERBOSE 1
-#else
-# define MGNERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef MGNTOKEN_TABLE
-# define MGNTOKEN_TABLE 0
-#endif
-
 #if ! defined MGNSTYPE && ! defined MGNSTYPE_IS_DECLARED
 typedef union MGNSTYPE
-#line 77 "../../../src/mbkmg/src/mg2mbk_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 77 "./mg2mbk_y.y"
+
 	char *s;
 	long n;
 	struct pxy {
 		long x;
 		long y;
 	} *p;
-}
-/* Line 187 of yacc.c.  */
-#line 214 "y.tab.c"
-	MGNSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 230 "y.tab.c"
+} MGNSTYPE;
+# define MGNSTYPE_IS_TRIVIAL 1
 # define mgnstype MGNSTYPE /* obsolescent; will be withdrawn */
 # define MGNSTYPE_IS_DECLARED 1
-# define MGNSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 227 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 242 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -298,14 +313,14 @@ typedef short int mgntype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-MGNID (int i)
+MGNID (int mgni)
 #else
 static int
-MGNID (i)
-    int i;
+MGNID (mgni)
+    int mgni;
 #endif
 {
-  return i;
+  return mgni;
 }
 #endif
 
@@ -386,9 +401,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union mgnalloc
 {
-  mgntype_int16 mgnss;
-  MGNSTYPE mgnvs;
-  };
+  mgntype_int16 mgnss_alloc;
+  MGNSTYPE mgnvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define MGNSTACK_GAP_MAXIMUM (sizeof (union mgnalloc) - 1)
@@ -422,12 +437,12 @@ union mgnalloc
    elements in the stack, and MGNPTR gives the new location of the
    stack.  Advance MGNPTR to a properly aligned location for the next
    stack.  */
-# define MGNSTACK_RELOCATE(Stack)					\
+# define MGNSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	MGNSIZE_T mgnnewbytes;						\
-	MGNCOPY (&mgnptr->Stack, Stack, mgnsize);				\
-	Stack = &mgnptr->Stack;						\
+	MGNCOPY (&mgnptr->Stack_alloc, Stack, mgnsize);			\
+	Stack = &mgnptr->Stack_alloc;					\
 	mgnnewbytes = mgnstacksize * sizeof (*Stack) + MGNSTACK_GAP_MAXIMUM; \
 	mgnptr += mgnnewbytes / sizeof (*mgnptr);				\
       }									\
@@ -549,7 +564,7 @@ static const char *const mgntname[] =
   "MBOTTOM", "AT", "MX", "MY", "R", "NTR", "PTR", "COP", "CON", "COPS",
   "COPW", "CONW", "PVIA", "CXN", "CXP", "STRING", "NUM", "'{'", "'}'",
   "'='", "';'", "'('", "')'", "','", "$accept", "design", "cells",
-  "leafcell", "lines", "line", "elm", "@1", "point", "point_list", "dir",
+  "leafcell", "lines", "line", "elm", "$@1", "point", "point_list", "dir",
   "face", "op", 0
 };
 #endif
@@ -895,17 +910,20 @@ mgn_symbol_print (mgnoutput, mgntype, mgnvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-mgn_stack_print (mgntype_int16 *bottom, mgntype_int16 *top)
+mgn_stack_print (mgntype_int16 *mgnbottom, mgntype_int16 *mgntop)
 #else
 static void
-mgn_stack_print (bottom, top)
-    mgntype_int16 *bottom;
-    mgntype_int16 *top;
+mgn_stack_print (mgnbottom, mgntop)
+    mgntype_int16 *mgnbottom;
+    mgntype_int16 *mgntop;
 #endif
 {
   MGNFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    MGNFPRINTF (stderr, " %d", *bottom);
+  for (; mgnbottom <= mgntop; mgnbottom++)
+    {
+      int mgnbot = *mgnbottom;
+      MGNFPRINTF (stderr, " %d", mgnbot);
+    }
   MGNFPRINTF (stderr, "\n");
 }
 
@@ -939,11 +957,11 @@ mgn_reduce_print (mgnvsp, mgnrule)
   /* The symbols being reduced.  */
   for (mgni = 0; mgni < mgnnrhs; mgni++)
     {
-      fprintf (stderr, "   $%d = ", mgni + 1);
+      MGNFPRINTF (stderr, "   $%d = ", mgni + 1);
       mgn_symbol_print (stderr, mgnrhs[mgnprhs[mgnrule] + mgni],
 		       &(mgnvsp[(mgni + 1) - (mgnnrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      MGNFPRINTF (stderr, "\n");
     }
 }
 
@@ -1223,10 +1241,8 @@ mgndestruct (mgnmsg, mgntype, mgnvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef MGNPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int mgnparse (void *MGNPARSE_PARAM);
@@ -1242,11 +1258,10 @@ int mgnparse ();
 #endif /* ! MGNPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int mgnchar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 MGNSTYPE mgnlval;
 
 /* Number of syntax errors so far.  */
@@ -1254,9 +1269,9 @@ int mgnnerrs;
 
 
 
-/*----------.
-| mgnparse.  |
-`----------*/
+/*-------------------------.
+| mgnparse or mgnpush_parse.  |
+`-------------------------*/
 
 #ifdef MGNPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1280,14 +1295,39 @@ mgnparse ()
 #endif
 #endif
 {
-  
-  int mgnstate;
+
+
+    int mgnstate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int mgnerrstatus;
+
+    /* The stacks and their tools:
+       `mgnss': related to states.
+       `mgnvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow mgnoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    mgntype_int16 mgnssa[MGNINITDEPTH];
+    mgntype_int16 *mgnss;
+    mgntype_int16 *mgnssp;
+
+    /* The semantic value stack.  */
+    MGNSTYPE mgnvsa[MGNINITDEPTH];
+    MGNSTYPE *mgnvs;
+    MGNSTYPE *mgnvsp;
+
+    MGNSIZE_T mgnstacksize;
+
   int mgnn;
   int mgnresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int mgnerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int mgntoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int mgntoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  MGNSTYPE mgnval;
+
 #if MGNERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char mgnmsgbuf[128];
@@ -1295,51 +1335,28 @@ mgnparse ()
   MGNSIZE_T mgnmsg_alloc = sizeof mgnmsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `mgnss': related to states,
-     `mgnvs': related to semantic values,
-     `mgnls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow mgnoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  mgntype_int16 mgnssa[MGNINITDEPTH];
-  mgntype_int16 *mgnss = mgnssa;
-  mgntype_int16 *mgnssp;
-
-  /* The semantic value stack.  */
-  MGNSTYPE mgnvsa[MGNINITDEPTH];
-  MGNSTYPE *mgnvs = mgnvsa;
-  MGNSTYPE *mgnvsp;
-
-
-
 #define MGNPOPSTACK(N)   (mgnvsp -= (N), mgnssp -= (N))
 
-  MGNSIZE_T mgnstacksize = MGNINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  MGNSTYPE mgnval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int mgnlen = 0;
 
+  mgntoken = 0;
+  mgnss = mgnssa;
+  mgnvs = mgnvsa;
+  mgnstacksize = MGNINITDEPTH;
+
   MGNDPRINTF ((stderr, "Starting parse\n"));
 
   mgnstate = 0;
   mgnerrstatus = 0;
   mgnnerrs = 0;
-  mgnchar = MGNEMPTY;		/* Cause a token to be read.  */
+  mgnchar = MGNEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   mgnssp = mgnss;
   mgnvsp = mgnvs;
 
@@ -1369,7 +1386,6 @@ mgnparse ()
 	MGNSTYPE *mgnvs1 = mgnvs;
 	mgntype_int16 *mgnss1 = mgnss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1377,7 +1393,6 @@ mgnparse ()
 	mgnoverflow (MGN_("memory exhausted"),
 		    &mgnss1, mgnsize * sizeof (*mgnssp),
 		    &mgnvs1, mgnsize * sizeof (*mgnvsp),
-
 		    &mgnstacksize);
 
 	mgnss = mgnss1;
@@ -1400,9 +1415,8 @@ mgnparse ()
 	  (union mgnalloc *) MGNSTACK_ALLOC (MGNSTACK_BYTES (mgnstacksize));
 	if (! mgnptr)
 	  goto mgnexhaustedlab;
-	MGNSTACK_RELOCATE (mgnss);
-	MGNSTACK_RELOCATE (mgnvs);
-
+	MGNSTACK_RELOCATE (mgnss_alloc, mgnss);
+	MGNSTACK_RELOCATE (mgnvs_alloc, mgnvs);
 #  undef MGNSTACK_RELOCATE
 	if (mgnss1 != mgnssa)
 	  MGNSTACK_FREE (mgnss1);
@@ -1413,7 +1427,6 @@ mgnparse ()
       mgnssp = mgnss + mgnsize - 1;
       mgnvsp = mgnvs + mgnsize - 1;
 
-
       MGNDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) mgnstacksize));
 
@@ -1423,6 +1436,9 @@ mgnparse ()
 
   MGNDPRINTF ((stderr, "Entering state %d\n", mgnstate));
 
+  if (mgnstate == MGNFINAL)
+    MGNACCEPT;
+
   goto mgnbackup;
 
 /*-----------.
@@ -1431,16 +1447,16 @@ mgnparse ()
 mgnbackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   mgnn = mgnpact[mgnstate];
   if (mgnn == MGNPACT_NINF)
     goto mgndefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* MGNCHAR is either MGNEMPTY or MGNEOF or a valid look-ahead symbol.  */
+  /* MGNCHAR is either MGNEMPTY or MGNEOF or a valid lookahead symbol.  */
   if (mgnchar == MGNEMPTY)
     {
       MGNDPRINTF ((stderr, "Reading a token: "));
@@ -1472,20 +1488,16 @@ mgnbackup:
       goto mgnreduce;
     }
 
-  if (mgnn == MGNFINAL)
-    MGNACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (mgnerrstatus)
     mgnerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   MGN_SYMBOL_PRINT ("Shifting", mgntoken, &mgnlval, &mgnlloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (mgnchar != MGNEOF)
-    mgnchar = MGNEMPTY;
+  /* Discard the shifted token.  */
+  mgnchar = MGNEMPTY;
 
   mgnstate = mgnn;
   *++mgnvsp = mgnlval;
@@ -1525,21 +1537,27 @@ mgnreduce:
   switch (mgnn)
     {
         case 5:
-#line 134 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 134 "./mg2mbk_y.y"
     {
 			mbkfree((mgnvsp[(2) - (5)].s));
 		}
     break;
 
   case 8:
-#line 144 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 144 "./mg2mbk_y.y"
     {
 			mbkfree((mgnvsp[(2) - (5)].s));
 		}
     break;
 
   case 9:
-#line 148 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 148 "./mg2mbk_y.y"
     {
 			if (!strcmp((mgnvsp[(4) - (10)].s), "ref_ref") || !strcmp((mgnvsp[(4) - (10)].s), "ref_con"))
 				addphref(mgleaf, (mgnvsp[(4) - (10)].s), checkrefname((mgnvsp[(2) - (10)].s)), (mgnvsp[(8) - (10)].p)->x, (mgnvsp[(8) - (10)].p)->y);
@@ -1552,7 +1570,9 @@ mgnreduce:
     break;
 
   case 11:
-#line 161 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 161 "./mg2mbk_y.y"
     {
 			if (strncmp((mgnvsp[(3) - (8)].s), "zd", 2)) {
 				fprintf(stderr, "modgen parser warning : ra not for ab box\n");
@@ -1566,7 +1586,9 @@ mgnreduce:
     break;
 
   case 12:
-#line 172 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 172 "./mg2mbk_y.y"
     {
 			if (strcmp((mgnvsp[(2) - (13)].s), "ul") && strcmp((mgnvsp[(2) - (13)].s), "ur")
 					&& strcmp((mgnvsp[(2) - (13)].s), "lr") && strcmp((mgnvsp[(2) - (13)].s), "ll"))
@@ -1579,7 +1601,9 @@ mgnreduce:
     break;
 
   case 13:
-#line 182 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 182 "./mg2mbk_y.y"
     {
 		char layer = mbk_layer((mgnvsp[(3) - (12)].s));
 		int x1 = (mgnvsp[(9) - (12)].p)->x, y1 = (mgnvsp[(9) - (12)].p)->y, x2 = (mgnvsp[(11) - (12)].p)->x, y2 = (mgnvsp[(11) - (12)].p)->y;
@@ -1609,12 +1633,16 @@ mgnreduce:
     break;
 
   case 14:
-#line 208 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 208 "./mg2mbk_y.y"
     {pl = NULL;}
     break;
 
   case 15:
-#line 209 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 209 "./mg2mbk_y.y"
     {
 		chain_list *l;
 		int x1, y1, x2, y2;
@@ -1663,7 +1691,9 @@ mgnreduce:
     break;
 
   case 16:
-#line 255 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 255 "./mg2mbk_y.y"
     { /* bounding box of transistors is knows for idps technology */
 		float tx; /* used to compute transistor bbox */
 		int x1, y1, x2, y2;
@@ -1696,7 +1726,9 @@ mgnreduce:
     break;
 
   case 17:
-#line 285 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 285 "./mg2mbk_y.y"
     { /* bounding box of transistors is knows for idps technology */
 		float tx; /* used to compute transistor bbox */
 		int x1, y1, x2, y2;
@@ -1729,7 +1761,9 @@ mgnreduce:
     break;
 
   case 18:
-#line 315 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 315 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_DIF_P, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1737,7 +1771,9 @@ mgnreduce:
     break;
 
   case 19:
-#line 320 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 320 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_DIF_N, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1745,7 +1781,9 @@ mgnreduce:
     break;
 
   case 20:
-#line 325 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 325 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_POLY, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1753,7 +1791,9 @@ mgnreduce:
     break;
 
   case 21:
-#line 330 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 330 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_BODY_P, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1761,7 +1801,9 @@ mgnreduce:
     break;
 
   case 22:
-#line 335 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 335 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_BODY_N, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1769,7 +1811,9 @@ mgnreduce:
     break;
 
   case 23:
-#line 340 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 340 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, CONT_VIA, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1777,7 +1821,9 @@ mgnreduce:
     break;
 
   case 24:
-#line 345 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 345 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, C_X_N, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1785,7 +1831,9 @@ mgnreduce:
     break;
 
   case 25:
-#line 350 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 350 "./mg2mbk_y.y"
     {
 			addphvia(mgleaf, C_X_P, (mgnvsp[(4) - (5)].p)->x, (mgnvsp[(4) - (5)].p)->y, 0, 0,NULL);
 			mbkfree((mgnvsp[(4) - (5)].p));
@@ -1793,7 +1841,9 @@ mgnreduce:
     break;
 
   case 26:
-#line 357 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 357 "./mg2mbk_y.y"
     {
 		struct pxy *pp;
 
@@ -1805,71 +1855,97 @@ mgnreduce:
     break;
 
   case 27:
-#line 368 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 368 "./mg2mbk_y.y"
     {
 			pl = addchain(pl, (void *)(mgnvsp[(1) - (1)].p));
 		}
     break;
 
   case 28:
-#line 372 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 372 "./mg2mbk_y.y"
     {
 			pl = addchain(pl, (void *)(mgnvsp[(1) - (3)].p));
 		}
     break;
 
   case 29:
-#line 377 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 377 "./mg2mbk_y.y"
     {(mgnval.n) = (long)HORIZ;}
     break;
 
   case 30:
-#line 378 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 378 "./mg2mbk_y.y"
     {(mgnval.n) = (long)VERTI;}
     break;
 
   case 31:
-#line 381 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 381 "./mg2mbk_y.y"
     {(mgnval.n) = (long)WEST;}
     break;
 
   case 32:
-#line 382 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 382 "./mg2mbk_y.y"
     {(mgnval.n) = (long)EAST;}
     break;
 
   case 33:
-#line 383 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 383 "./mg2mbk_y.y"
     {(mgnval.n) = (long)SOUTH;}
     break;
 
   case 34:
-#line 384 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 384 "./mg2mbk_y.y"
     {(mgnval.n) = (long)NORTH;}
     break;
 
   case 35:
-#line 387 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 387 "./mg2mbk_y.y"
     {(mgnval.n) = (long)NOSYM;}
     break;
 
   case 36:
-#line 389 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 389 "./mg2mbk_y.y"
     {(mgnval.n) = (long)SYM_Y;}
     break;
 
   case 37:
-#line 391 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 391 "./mg2mbk_y.y"
     {(mgnval.n) = (long)SYM_X;}
     break;
 
   case 38:
-#line 393 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 393 "./mg2mbk_y.y"
     {(mgnval.n) = (long)SYMXY;}
     break;
 
   case 39:
-#line 395 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 395 "./mg2mbk_y.y"
     {
 			if ((mgnvsp[(2) - (2)].n) / SCALE_X / TWO == 90)
 				(mgnval.n) = (long)ROT_P;
@@ -1879,7 +1955,9 @@ mgnreduce:
     break;
 
   case 40:
-#line 402 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 402 "./mg2mbk_y.y"
     {
 			if ((mgnvsp[(3) - (3)].n) / SCALE_X / TWO == 90)
 				(mgnval.n) = (long)SY_RM;
@@ -1889,7 +1967,9 @@ mgnreduce:
     break;
 
   case 41:
-#line 409 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 409 "./mg2mbk_y.y"
     {
 			if ((mgnvsp[(3) - (3)].n) / SCALE_X / TWO == 90)
 				(mgnval.n) = (long)SY_RP;
@@ -1899,8 +1979,9 @@ mgnreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1904 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1985 "y.tab.c"
       default: break;
     }
   MGN_SYMBOL_PRINT ("-> $$ =", mgnr1[mgnn], &mgnval, &mgnloc);
@@ -1911,7 +1992,6 @@ mgnreduce:
 
   *++mgnvsp = mgnval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1976,7 +2056,7 @@ mgnerrlab:
 
   if (mgnerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (mgnchar <= MGNEOF)
@@ -1993,7 +2073,7 @@ mgnerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto mgnerrlab1;
 
@@ -2050,9 +2130,6 @@ mgnerrlab1:
       MGN_STACK_PRINT (mgnss, mgnssp);
     }
 
-  if (mgnn == MGNFINAL)
-    MGNACCEPT;
-
   *++mgnvsp = mgnlval;
 
 
@@ -2077,7 +2154,7 @@ mgnabortlab:
   mgnresult = 1;
   goto mgnreturn;
 
-#ifndef mgnoverflow
+#if !defined(mgnoverflow) || MGNERROR_VERBOSE
 /*-------------------------------------------------.
 | mgnexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2088,7 +2165,7 @@ mgnexhaustedlab:
 #endif
 
 mgnreturn:
-  if (mgnchar != MGNEOF && mgnchar != MGNEMPTY)
+  if (mgnchar != MGNEMPTY)
      mgndestruct ("Cleanup: discarding lookahead",
 		 mgntoken, &mgnlval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2114,7 +2191,9 @@ mgnreturn:
 }
 
 
-#line 417 "../../../src/mbkmg/src/mg2mbk_y.y"
+
+/* Line 1675 of yacc.c  */
+#line 417 "./mg2mbk_y.y"
 
 char *
 	filenameforlex()
