@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,10 +28,11 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+
 /* Tokens.  */
 #ifndef MVL_Y_TOKENTYPE
 # define MVL_Y_TOKENTYPE
@@ -302,21 +302,27 @@
 
 #if ! defined MVL_Y_STYPE && ! defined MVL_Y_STYPE_IS_DECLARED
 typedef union MVL_Y_STYPE
-#line 36 "../../../src/mbkvhdl/src/mvl_scomp_y.y"
 {
+
+/* Line 1676 of yacc.c  */
+#line 36 "./mvl_scomp_y.y"
+
   long        valu;
   char       *text;
   char        flag;
   mvl_name    name;
   mvl_expr    expr;
-  }
-/* Line 1489 of yacc.c.  */
-#line 315 "y.tab.h"
-	MVL_Y_STYPE;
+  
+
+
+/* Line 1676 of yacc.c  */
+#line 320 "y.tab.h"
+} MVL_Y_STYPE;
+# define MVL_Y_STYPE_IS_TRIVIAL 1
 # define mvl_y_stype MVL_Y_STYPE /* obsolescent; will be withdrawn */
 # define MVL_Y_STYPE_IS_DECLARED 1
-# define MVL_Y_STYPE_IS_TRIVIAL 1
 #endif
 
 extern MVL_Y_STYPE mvl_y_lval;
 
+
