@@ -13,9 +13,10 @@
 /*		  mvl_initab , mvl_deltab, 				*/
 /*									*/
 /* ###--------------------------------------------------------------### */
-#ident "$Id: mvl_util.c,v 1.1.1.1 2002/04/26 09:51:07 ludo Exp $"
+#ident "$Id: mvl_util.c,v 1.2 2009/06/14 13:51:56 ludo Exp $"
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include <mut.h>
 #include <mlo.h>
 #include "mvl_utype.h"
@@ -32,15 +33,15 @@ struct dct_entry **head;
 char              *key_str;
 char              *ctx_str;
 
-  {
-  int               found = 0;
-  int               index;
+{
+  long              found = 0;
+  long              index;
   struct dct_entry *entry_pnt;
   struct dct_entry *last_entry = NULL;
   struct dct_recrd *recrd_pnt;
   struct dct_recrd *last_recrd = NULL;
 
-  index     = (int)key_str % MVL_HSZDFN;
+  index     = (long)key_str % MVL_HSZDFN;
   entry_pnt = head [index];
 
   while (entry_pnt != NULL)
@@ -91,7 +92,7 @@ char              *ctx_str;
         }
       }
     }
-  }
+}
 
 /* ###--------------------------------------------------------------### */
 /*  function : mvl_initab						*/
@@ -100,7 +101,7 @@ struct dct_entry **mvl_initab ()
 
   {
   struct dct_entry **head;
-  int                i;
+  long                i;
 
   head = (struct dct_entry **)
          mbkalloc (sizeof(struct dct_entry *) * MVL_HSZDFN);
@@ -116,7 +117,7 @@ struct dct_entry **mvl_initab ()
 /*  content  : print out warning messages on the standard error output  */
 /* ###--------------------------------------------------------------### */
 void mvl_warning (code,str1)
-int   code;
+long   code;
 char *str1;
   {
   static char first_time = 0;
@@ -151,10 +152,10 @@ char *str1;
 /* ###--------------------------------------------------------------### */
 void mvl_toolbug (code,str1,str2,nbr1)
 
-int   code;
+long   code;
 char *str1;
 char *str2;
-int   nbr1;
+long   nbr1;
 
   {
   (void) fprintf (stderr,"Fatal error %d executing `%s`: ", code,str1);
@@ -174,9 +175,9 @@ int   nbr1;
 /* ###--------------------------------------------------------------### */
 void mvl_message (code,str1,nmb1)
 
-int   code;
+long   code;
 char *str1;
-int   nmb1;
+long   nmb1;
 
   {
   switch (code)
@@ -194,16 +195,16 @@ void mvl_addtab (head,key_str,ctx_str,field,valu)
 struct dct_entry **head;
 char              *key_str;
 char              *ctx_str;
-int                field;
-int                valu;
+long                field;
+long                valu;
 
   {
-  int               found = 0;
-  int               index;
+  long               found = 0;
+  long               index;
   struct dct_entry *entry_pnt;
   struct dct_recrd *recrd_pnt;
 
-  index     = (int) key_str % MVL_HSZDFN;
+  index     = (long) key_str % MVL_HSZDFN;
   entry_pnt = head[index];
 
   while (entry_pnt != NULL)
@@ -273,20 +274,20 @@ int                valu;
 /* ###--------------------------------------------------------------### */
 /*  function : mvl_chktab						*/
 /* ###--------------------------------------------------------------### */
-int  mvl_chktab (head,key_str,ctx_str,field)
+long  mvl_chktab (head,key_str,ctx_str,field)
 
 struct dct_entry **head;
 char              *key_str;
 char              *ctx_str;
-int                field;
+long                field;
 
   {
-  int               found = 0;
-  int               valu = 0;
+  long               found = 0;
+  long               valu = 0;
   struct dct_entry *entry_pnt;
   struct dct_recrd *recrd_pnt;
 
-  entry_pnt = head [(int)key_str % MVL_HSZDFN];
+  entry_pnt = head [(long)key_str % MVL_HSZDFN];
 
   while (entry_pnt != NULL)
     {
@@ -356,7 +357,7 @@ struct dct_entry **pt_hash;
   struct dct_entry *pt_entry;
   struct dct_entry *pt_nxtentry;
   struct dct_recrd *pt_record;
-  int               i;
+  long               i;
 
   if (pt_hash != NULL)
     {
@@ -390,7 +391,7 @@ struct dct_entry **pt_hash;
 /* ###--------------------------------------------------------------### */
 void mvl_error (code,str1)
 
-int   code;
+long   code;
 char *str1;
 
   {
@@ -512,7 +513,7 @@ char             *key;
 
   {
   struct dct_entry *entry;
-  int               i;
+  long               i;
 
   if (MVL_DCEHED == NULL)
     {
@@ -548,7 +549,7 @@ char             *key;
 
   {
   struct dct_recrd *recrd;
-  int               i;
+  long               i;
 
   if (MVL_DCRHED == NULL)
     {
@@ -620,7 +621,7 @@ char *name;
   char                     *prv_name;
   char                     *tmp_name;
   char                      buffer[200];
-  int                       i,j,flag,number;
+  long                       i,j,flag,number;
   static struct dct_entry **namtab=NULL;
 
   if (namtab == NULL)
@@ -667,7 +668,7 @@ char *name;
       new_name = namealloc (buffer);
       }
     mvl_addtab (namtab,new_name,NULL,MVL_NEWDFN,1);
-    mvl_addtab (namtab,tmp_name,NULL,MVL_PNTDFN,(int)new_name);
+    mvl_addtab (namtab,tmp_name,NULL,MVL_PNTDFN,(long)new_name);
     mvl_addtab (namtab,tmp_name,NULL,MVL_NAMDFN,1);
     }
 
@@ -710,7 +711,7 @@ char *new_name;
 void *mvl_vectnam(pt_list,left,right,name,type)
   
 void *pt_list;
-int *left, *right;
+long *left, *right;
 char **name;
 char type;
 
