@@ -18,7 +18,7 @@
  * 
  * You should have received a copy  of the GNU General Public License along
  * with the GNU C Library; see the  file COPYING. If not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /* 
@@ -29,7 +29,7 @@
  * Modified by Mourad Aberbour in Sept. 1997 
  */
 
-#ident "$Id: drive_vlog.c,v 1.2 2002/09/30 16:20:59 czo Exp $"
+#ident "$Id: drive_vlog.c,v 1.3 2012/05/14 14:20:26 alliance Exp $"
 
 #include <mut.h> 
 #include <mlo.h>
