@@ -1,7 +1,7 @@
 
 // -*- C++ -*-
 //
-// $Id: MDefs.h,v 1.8 2005/10/10 15:34:05 jpc Exp $
+// $Id: MDefs.h,v 1.9 2008/06/11 09:20:34 jpc Exp $
 //
 // /-----------------------------------------------------------------\ 
 // |                                                                 |
@@ -25,6 +25,8 @@
 
 
 # include  "UDefs.h"
+# include <limits.h>
+# include <string.h>
 
 
 
