@@ -1,7 +1,7 @@
 
 // -*- C++ -*-
 //
-// $Id: MMBK.cpp,v 1.9 2008/06/11 09:20:34 jpc Exp $
+// $Id: MMBK.cpp,v 1.10 2012/05/02 14:49:23 jpc Exp $
 //
 // /-----------------------------------------------------------------\ 
 // |                                                                 |
@@ -197,25 +197,27 @@ CEnv::CEnv (void)
 
   // Copy constants values from constants namespace ("D::").
   // Routing constants, loaded now that we have SCALE_X.
-  D::X_GRID             = ::MBK::SCALE (D::_X_GRID);
-  D::Y_GRID             = ::MBK::SCALE (D::_Y_GRID);
-  D::WIDTH_VSS          = ::MBK::SCALE (D::_WIDTH_VSS);
-  D::WIDTH_VDD          = ::MBK::SCALE (D::_WIDTH_VDD);
-  D::Y_SLICE            = ::MBK::SCALE (D::_Y_SLICE);
-  D::TRACK_WIDTH_ALU1   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU1);
-  D::TRACK_WIDTH_ALU2   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU2);
-  D::TRACK_WIDTH_ALU3   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU3);
-  D::TRACK_WIDTH_ALU4   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU4);
-  D::TRACK_WIDTH_ALU5   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU5);
-  D::TRACK_WIDTH_ALU6   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU6);
-  D::TRACK_WIDTH_ALU7   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU7);
-  D::TRACK_SPACING_ALU1 = ::MBK::SCALE (D::_TRACK_SPACING_ALU1);
-  D::TRACK_SPACING_ALU2 = ::MBK::SCALE (D::_TRACK_SPACING_ALU2);
-  D::TRACK_SPACING_ALU3 = ::MBK::SCALE (D::_TRACK_SPACING_ALU3);
-  D::TRACK_SPACING_ALU4 = ::MBK::SCALE (D::_TRACK_SPACING_ALU4);
-  D::TRACK_SPACING_ALU5 = ::MBK::SCALE (D::_TRACK_SPACING_ALU5);
-  D::TRACK_SPACING_ALU6 = ::MBK::SCALE (D::_TRACK_SPACING_ALU6);
-  D::TRACK_SPACING_ALU7 = ::MBK::SCALE (D::_TRACK_SPACING_ALU7);
+  D::X_GRID             = ::MBK::SCALE (MBK_X_GRID);
+  D::Y_GRID             = ::MBK::SCALE (MBK_Y_GRID);
+  D::WIDTH_VSS          = ::MBK::SCALE (MBK_WIDTH_VSS);
+  D::WIDTH_VDD          = ::MBK::SCALE (MBK_WIDTH_VDD);
+  D::Y_SLICE            = ::MBK::SCALE (MBK_Y_SLICE);
+  D::TRACK_WIDTH_ALU1   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU1);
+  D::TRACK_WIDTH_ALU2   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU2);
+  D::TRACK_WIDTH_ALU3   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU3);
+  D::TRACK_WIDTH_ALU4   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU4);
+  D::TRACK_WIDTH_ALU5   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU5);
+  D::TRACK_WIDTH_ALU6   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU6);
+  D::TRACK_WIDTH_ALU7   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU7);
+  D::TRACK_WIDTH_ALU8   = ::MBK::SCALE (MBK_TRACK_WIDTH_ALU8);
+  D::TRACK_SPACING_ALU1 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU1);
+  D::TRACK_SPACING_ALU2 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU2);
+  D::TRACK_SPACING_ALU3 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU3);
+  D::TRACK_SPACING_ALU4 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU4);
+  D::TRACK_SPACING_ALU5 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU5);
+  D::TRACK_SPACING_ALU6 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU6);
+  D::TRACK_SPACING_ALU7 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU7);
+  D::TRACK_SPACING_ALU8 = ::MBK::SCALE (MBK_TRACK_SPACING_ALU8);
 
   // Grid spacing.
   grid_dx = D::X_GRID;
@@ -229,6 +231,7 @@ CEnv::CEnv (void)
   ALU2W[ALU5]  = D::TRACK_WIDTH_ALU5;
   ALU2W[ALU6]  = D::TRACK_WIDTH_ALU6;
   ALU2W[ALU7]  = D::TRACK_WIDTH_ALU7;
+  ALU2W[ALU8]  = D::TRACK_WIDTH_ALU8;
   ALU2W[CALU1] = D::TRACK_WIDTH_ALU1;
   ALU2W[CALU2] = D::TRACK_WIDTH_ALU2;
   ALU2W[CALU3] = D::TRACK_WIDTH_ALU3;
@@ -236,6 +239,7 @@ CEnv::CEnv (void)
   ALU2W[CALU5] = D::TRACK_WIDTH_ALU5;
   ALU2W[CALU6] = D::TRACK_WIDTH_ALU6;
   ALU2W[CALU7] = D::TRACK_WIDTH_ALU7;
+  ALU2W[CALU8] = D::TRACK_WIDTH_ALU8;
   ALU2W[TALU1] = D::TRACK_WIDTH_ALU1;
   ALU2W[TALU2] = D::TRACK_WIDTH_ALU2;
   ALU2W[TALU3] = D::TRACK_WIDTH_ALU3;
@@ -243,6 +247,7 @@ CEnv::CEnv (void)
   ALU2W[TALU5] = D::TRACK_WIDTH_ALU5;
   ALU2W[TALU6] = D::TRACK_WIDTH_ALU6;
   ALU2W[TALU7] = D::TRACK_WIDTH_ALU7;
+  ALU2W[TALU8] = D::TRACK_WIDTH_ALU8;
 
   // Layers minimal width.
   ALU2S[ALU1]  = D::TRACK_SPACING_ALU1;
@@ -252,6 +257,7 @@ CEnv::CEnv (void)
   ALU2S[ALU5]  = D::TRACK_SPACING_ALU5;
   ALU2S[ALU6]  = D::TRACK_SPACING_ALU6;
   ALU2S[ALU7]  = D::TRACK_SPACING_ALU7;
+  ALU2S[ALU8]  = D::TRACK_SPACING_ALU8;
   ALU2S[CALU1] = D::TRACK_SPACING_ALU1;
   ALU2S[CALU2] = D::TRACK_SPACING_ALU2;
   ALU2S[CALU3] = D::TRACK_SPACING_ALU3;
@@ -259,6 +265,7 @@ CEnv::CEnv (void)
   ALU2S[CALU5] = D::TRACK_SPACING_ALU5;
   ALU2S[CALU6] = D::TRACK_SPACING_ALU6;
   ALU2S[CALU7] = D::TRACK_SPACING_ALU7;
+  ALU2S[CALU8] = D::TRACK_SPACING_ALU8;
   ALU2S[TALU1] = D::TRACK_SPACING_ALU1;
   ALU2S[TALU2] = D::TRACK_SPACING_ALU2;
   ALU2S[TALU3] = D::TRACK_SPACING_ALU3;
@@ -266,6 +273,7 @@ CEnv::CEnv (void)
   ALU2S[TALU5] = D::TRACK_SPACING_ALU5;
   ALU2S[TALU6] = D::TRACK_SPACING_ALU6;
   ALU2S[TALU7] = D::TRACK_SPACING_ALU7;
+  ALU2S[TALU8] = D::TRACK_SPACING_ALU8;
 
   // Layer to Z translation table.
   ALU2Z[ALU1]  = 0;
@@ -275,6 +283,7 @@ CEnv::CEnv (void)
   ALU2Z[ALU5]  = 4;
   ALU2Z[ALU6]  = 5;
   ALU2Z[ALU7]  = 6;
+  ALU2Z[ALU8]  = 7;
   ALU2Z[CALU1] = 0;
   ALU2Z[CALU2] = 1;
   ALU2Z[CALU3] = 2;
@@ -282,6 +291,7 @@ CEnv::CEnv (void)
   ALU2Z[CALU5] = 4;
   ALU2Z[CALU6] = 5;
   ALU2Z[CALU7] = 6;
+  ALU2Z[CALU8] = 7;
   ALU2Z[TALU1] = 0;
   ALU2Z[TALU2] = 1;
   ALU2Z[TALU3] = 2;
@@ -289,6 +299,7 @@ CEnv::CEnv (void)
   ALU2Z[TALU5] = 4;
   ALU2Z[TALU6] = 5;
   ALU2Z[TALU7] = 6;
+  ALU2Z[TALU8] = 7;
 
   regcomp(&pxLibRegex,"p.*px",REG_EXTENDED|REG_NOSUB);
 }
