@@ -1,7 +1,7 @@
 
 // -*- C++ -*-
 //
-// $Id: MNet.cpp,v 1.8 2005/02/17 14:47:27 jpc Exp $
+// $Id: MNet.cpp,v 1.12 2006/04/28 07:51:54 jpc Exp $
 //
 //  /----------------------------------------------------------------\ 
 //  |                                                                |
@@ -254,9 +254,12 @@ void  CTerm::lockalone (bool global)
 
   if (nodes.size() != 1) return;
 
+
   coord  = nodes.back ();
   coord2 = coord;
 
+  CDRGrid* drgrid = coord._drgrid;
+
   if ( (coord.z() > 0) && !global ) return;
   if (  coord.onAB()) return;
 
@@ -293,6 +296,7 @@ void  CTerm::lockalone (bool global)
   }
 
 
+  if ( drgrid->Z < 3 ) return;
   // Global terminal : when zupper=4, find the nearest VIA on the
   // double pitch grid.
 
@@ -333,6 +337,8 @@ void  CTerm::lockalone (bool global)
     }
   }
 
+  if ( drgrid->Z < 4 ) return;
+
   if (coord.z() < 4) {
     // Go to z=3 (ALU3).
     //cerr << "+   locking z=3          " << coord2 << endl;
@@ -391,13 +397,16 @@ ostream  &operator<< (ostream &o, CTerm &self)
 // Constructor  :  "CNet::CNet()".
 
 CNet::CNet (CDRGrid *drgrid, string netName)
+  : pri(0)
+  , name(netName)
+  , terms()
+  , rtree(NULL)
+  , bb()
+  , size(0)
+  , external(false)
+  , fixed(false)
+  , _drgrid(drgrid)
 {
-  name     = netName;
-  external = false;
-  pri      = 0;
-  size     = 0;
-  rtree    = NULL;
-  _drgrid  = drgrid;
 }
 
 
@@ -446,8 +455,9 @@ bool CNet::global (bool rglobal)
 
 void CNet::newaccess (string termName, int x, int y, int z)
 {
-  CRect  rect;
+  if ( z >= _drgrid->Z ) return;
 
+  CRect  rect;
 
   rect.x1 = rect.x2 = x;
   rect.y1 = rect.y2 = y;
@@ -463,6 +473,8 @@ void CNet::newaccess (string termName, int x, int y, int z)
 
 void CNet::newaccess (string termName, CRect &rect, int z)
 {
+  if ( z >= _drgrid->Z ) return;
+
   CCoord  coord;
   int     id, mergeid;
 
@@ -489,7 +501,13 @@ void CNet::newaccess (string termName, CRect &rect, int z)
     }
 
     catch (merge_term &e) {
-      mergeid = e.id;
+      if ( e.id > id ) {
+        mergeid = id;
+        id      = e.id;
+      } else {
+        mergeid = e.id;
+      }
+      cerr << "Merging terminals : [" << id << "] absorbed by [" << mergeid << "]" << endl;
 
       // Merge terminals ...
       terms[mergeid]->merge (terms[id], mergeid, this);
@@ -502,6 +520,7 @@ void CNet::newaccess (string termName, CRect &rect, int z)
 
       // Re-computes the terminal's ids.
       for (id = 0; id < size; id++) terms[id]->setid (id);
+      cerr << "New terminal max id " << id-1 << endl;
 
       id = mergeid;
     }
