@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define PAT_DECL_Y_BISON 1
 
 /* Bison version.  */
-#define PAT_DECL_Y_BISON_VERSION "2.3"
+#define PAT_DECL_Y_BISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define PAT_DECL_Y_SKELETON_NAME "yacc.c"
@@ -55,96 +54,21 @@
 /* Pure parsers.  */
 #define PAT_DECL_Y_PURE 0
 
+/* Push parsers.  */
+#define PAT_DECL_Y_PUSH 0
+
+/* Pull parsers.  */
+#define PAT_DECL_Y_PULL 1
+
 /* Using locations.  */
 #define PAT_DECL_Y_LSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef PAT_DECL_Y_TOKENTYPE
-# define PAT_DECL_Y_TOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum pat_decl_y_tokentype {
-     _GTSym = 258,
-     _IN = 259,
-     _INOUT = 260,
-     _LESym = 261,
-     _LTSym = 262,
-     _OUT = 263,
-     AbstractLit = 264,
-     BitStringLit = 265,
-     BEGIN_ = 266,
-     Colon = 267,
-     Comma = 268,
-     Comment = 269,
-     DOWNTO = 270,
-     Dot = 271,
-     END_ = 272,
-     FS = 273,
-     Format = 274,
-     INSPECT = 275,
-     Identifier = 276,
-     LeftParen = 277,
-     Literal = 278,
-     NS = 279,
-     MS = 280,
-     PS = 281,
-     Plus = 282,
-     REGISTER = 283,
-     RightParen = 284,
-     SAVE = 285,
-     SIGNAL = 286,
-     Semicolons = 287,
-     SPY = 288,
-     TO = 289,
-     TRACE = 290,
-     US = 291,
-     UnknownChar = 292
-   };
-#endif
-/* Tokens.  */
-#define _GTSym 258
-#define _IN 259
-#define _INOUT 260
-#define _LESym 261
-#define _LTSym 262
-#define _OUT 263
-#define AbstractLit 264
-#define BitStringLit 265
-#define BEGIN_ 266
-#define Colon 267
-#define Comma 268
-#define Comment 269
-#define DOWNTO 270
-#define Dot 271
-#define END_ 272
-#define FS 273
-#define Format 274
-#define INSPECT 275
-#define Identifier 276
-#define LeftParen 277
-#define Literal 278
-#define NS 279
-#define MS 280
-#define PS 281
-#define Plus 282
-#define REGISTER 283
-#define RightParen 284
-#define SAVE 285
-#define SIGNAL 286
-#define Semicolons 287
-#define SPY 288
-#define TO 289
-#define TRACE 290
-#define US 291
-#define UnknownChar 292
-
-
-
-
 /* Copy the first part of user declarations.  */
-#line 32 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 189 of yacc.c  */
+#line 32 "./pat_decl_y.y"
 
 
 #include <stdio.h>
@@ -506,6 +430,9 @@ struct paseq  *ptseq ;
 
 
 
+/* Line 189 of yacc.c  */
+#line 435 "y.tab.c"
+
 /* Enabling traces.  */
 #ifndef PAT_DECL_Y_DEBUG
 # define PAT_DECL_Y_DEBUG 0
@@ -524,32 +451,120 @@ struct paseq  *ptseq ;
 # define PAT_DECL_Y_TOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef PAT_DECL_Y_TOKENTYPE
+# define PAT_DECL_Y_TOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum pat_decl_y_tokentype {
+     _GTSym = 258,
+     _IN = 259,
+     _INOUT = 260,
+     _LESym = 261,
+     _LTSym = 262,
+     _OUT = 263,
+     AbstractLit = 264,
+     BitStringLit = 265,
+     BEGIN_ = 266,
+     Colon = 267,
+     Comma = 268,
+     Comment = 269,
+     DOWNTO = 270,
+     Dot = 271,
+     END_ = 272,
+     FS = 273,
+     Format = 274,
+     INSPECT = 275,
+     Identifier = 276,
+     LeftParen = 277,
+     Literal = 278,
+     NS = 279,
+     MS = 280,
+     PS = 281,
+     Plus = 282,
+     REGISTER = 283,
+     RightParen = 284,
+     SAVE = 285,
+     SIGNAL = 286,
+     Semicolons = 287,
+     SPY = 288,
+     TO = 289,
+     TRACE = 290,
+     US = 291,
+     UnknownChar = 292
+   };
+#endif
+/* Tokens.  */
+#define _GTSym 258
+#define _IN 259
+#define _INOUT 260
+#define _LESym 261
+#define _LTSym 262
+#define _OUT 263
+#define AbstractLit 264
+#define BitStringLit 265
+#define BEGIN_ 266
+#define Colon 267
+#define Comma 268
+#define Comment 269
+#define DOWNTO 270
+#define Dot 271
+#define END_ 272
+#define FS 273
+#define Format 274
+#define INSPECT 275
+#define Identifier 276
+#define LeftParen 277
+#define Literal 278
+#define NS 279
+#define MS 280
+#define PS 281
+#define Plus 282
+#define REGISTER 283
+#define RightParen 284
+#define SAVE 285
+#define SIGNAL 286
+#define Semicolons 287
+#define SPY 288
+#define TO 289
+#define TRACE 290
+#define US 291
+#define UnknownChar 292
+
+
+
+
 #if ! defined PAT_DECL_Y_STYPE && ! defined PAT_DECL_Y_STYPE_IS_DECLARED
 typedef union PAT_DECL_Y_STYPE
-#line 394 "../../../src/ppt/src/pat_decl_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 394 "./pat_decl_y.y"
+
   int           valu;
   float         fval;
   char          immd;
   char         *text;
   struct array  arra;
   struct label  labe;
-  }
-/* Line 187 of yacc.c.  */
-#line 540 "y.tab.c"
-	PAT_DECL_Y_STYPE;
+  
+
+
+/* Line 214 of yacc.c  */
+#line 556 "y.tab.c"
+} PAT_DECL_Y_STYPE;
+# define PAT_DECL_Y_STYPE_IS_TRIVIAL 1
 # define pat_decl_y_stype PAT_DECL_Y_STYPE /* obsolescent; will be withdrawn */
 # define PAT_DECL_Y_STYPE_IS_DECLARED 1
-# define PAT_DECL_Y_STYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 553 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 568 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -624,14 +639,14 @@ typedef short int pat_decl_y_type_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-PAT_DECL_Y_ID (int i)
+PAT_DECL_Y_ID (int pat_decl_y_i)
 #else
 static int
-PAT_DECL_Y_ID (i)
-    int i;
+PAT_DECL_Y_ID (pat_decl_y_i)
+    int pat_decl_y_i;
 #endif
 {
-  return i;
+  return pat_decl_y_i;
 }
 #endif
 
@@ -712,9 +727,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union pat_decl_y_alloc
 {
-  pat_decl_y_type_int16 pat_decl_y_ss;
-  PAT_DECL_Y_STYPE pat_decl_y_vs;
-  };
+  pat_decl_y_type_int16 pat_decl_y_ss_alloc;
+  PAT_DECL_Y_STYPE pat_decl_y_vs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define PAT_DECL_Y_STACK_GAP_MAXIMUM (sizeof (union pat_decl_y_alloc) - 1)
@@ -748,12 +763,12 @@ union pat_decl_y_alloc
    elements in the stack, and PAT_DECL_Y_PTR gives the new location of the
    stack.  Advance PAT_DECL_Y_PTR to a properly aligned location for the next
    stack.  */
-# define PAT_DECL_Y_STACK_RELOCATE(Stack)					\
+# define PAT_DECL_Y_STACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	PAT_DECL_Y_SIZE_T pat_decl_y_newbytes;						\
-	PAT_DECL_Y_COPY (&pat_decl_y_ptr->Stack, Stack, pat_decl_y_size);				\
-	Stack = &pat_decl_y_ptr->Stack;						\
+	PAT_DECL_Y_COPY (&pat_decl_y_ptr->Stack_alloc, Stack, pat_decl_y_size);			\
+	Stack = &pat_decl_y_ptr->Stack_alloc;					\
 	pat_decl_y_newbytes = pat_decl_y_stacksize * sizeof (*Stack) + PAT_DECL_Y_STACK_GAP_MAXIMUM; \
 	pat_decl_y_ptr += pat_decl_y_newbytes / sizeof (*pat_decl_y_ptr);				\
       }									\
@@ -1173,17 +1188,20 @@ pat_decl_y__symbol_print (pat_decl_y_output, pat_decl_y_type, pat_decl_y_valuep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-pat_decl_y__stack_print (pat_decl_y_type_int16 *bottom, pat_decl_y_type_int16 *top)
+pat_decl_y__stack_print (pat_decl_y_type_int16 *pat_decl_y_bottom, pat_decl_y_type_int16 *pat_decl_y_top)
 #else
 static void
-pat_decl_y__stack_print (bottom, top)
-    pat_decl_y_type_int16 *bottom;
-    pat_decl_y_type_int16 *top;
+pat_decl_y__stack_print (pat_decl_y_bottom, pat_decl_y_top)
+    pat_decl_y_type_int16 *pat_decl_y_bottom;
+    pat_decl_y_type_int16 *pat_decl_y_top;
 #endif
 {
   PAT_DECL_Y_FPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    PAT_DECL_Y_FPRINTF (stderr, " %d", *bottom);
+  for (; pat_decl_y_bottom <= pat_decl_y_top; pat_decl_y_bottom++)
+    {
+      int pat_decl_y_bot = *pat_decl_y_bottom;
+      PAT_DECL_Y_FPRINTF (stderr, " %d", pat_decl_y_bot);
+    }
   PAT_DECL_Y_FPRINTF (stderr, "\n");
 }
 
@@ -1217,11 +1235,11 @@ pat_decl_y__reduce_print (pat_decl_y_vsp, pat_decl_y_rule)
   /* The symbols being reduced.  */
   for (pat_decl_y_i = 0; pat_decl_y_i < pat_decl_y_nrhs; pat_decl_y_i++)
     {
-      fprintf (stderr, "   $%d = ", pat_decl_y_i + 1);
+      PAT_DECL_Y_FPRINTF (stderr, "   $%d = ", pat_decl_y_i + 1);
       pat_decl_y__symbol_print (stderr, pat_decl_y_rhs[pat_decl_y_prhs[pat_decl_y_rule] + pat_decl_y_i],
 		       &(pat_decl_y_vsp[(pat_decl_y_i + 1) - (pat_decl_y_nrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      PAT_DECL_Y_FPRINTF (stderr, "\n");
     }
 }
 
@@ -1501,10 +1519,8 @@ pat_decl_y_destruct (pat_decl_y_msg, pat_decl_y_type, pat_decl_y_valuep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef PAT_DECL_Y_PARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int pat_decl_y_parse (void *PAT_DECL_Y_PARSE_PARAM);
@@ -1520,11 +1536,10 @@ int pat_decl_y_parse ();
 #endif /* ! PAT_DECL_Y_PARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 extern int pat_decl_y_char;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 extern PAT_DECL_Y_STYPE pat_decl_y_lval;
 
 /* Number of syntax errors so far.  */
@@ -1532,9 +1547,9 @@ extern int pat_decl_y_nerrs;
 
 
 
-/*----------.
-| pat_decl_y_parse.  |
-`----------*/
+/*-------------------------.
+| pat_decl_y_parse or pat_decl_y_push_parse.  |
+`-------------------------*/
 
 #ifdef PAT_DECL_Y_PARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1558,14 +1573,39 @@ pat_decl_y_parse ()
 #endif
 #endif
 {
-  
-  int pat_decl_y_state;
+
+
+    int pat_decl_y_state;
+    /* Number of tokens to shift before error messages enabled.  */
+    int pat_decl_y_errstatus;
+
+    /* The stacks and their tools:
+       `pat_decl_y_ss': related to states.
+       `pat_decl_y_vs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow pat_decl_y_overflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    pat_decl_y_type_int16 pat_decl_y_ssa[PAT_DECL_Y_INITDEPTH];
+    pat_decl_y_type_int16 *pat_decl_y_ss;
+    pat_decl_y_type_int16 *pat_decl_y_ssp;
+
+    /* The semantic value stack.  */
+    PAT_DECL_Y_STYPE pat_decl_y_vsa[PAT_DECL_Y_INITDEPTH];
+    PAT_DECL_Y_STYPE *pat_decl_y_vs;
+    PAT_DECL_Y_STYPE *pat_decl_y_vsp;
+
+    PAT_DECL_Y_SIZE_T pat_decl_y_stacksize;
+
   int pat_decl_y_n;
   int pat_decl_y_result;
-  /* Number of tokens to shift before error messages enabled.  */
-  int pat_decl_y_errstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int pat_decl_y_token = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int pat_decl_y_token;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  PAT_DECL_Y_STYPE pat_decl_y_val;
+
 #if PAT_DECL_Y_ERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char pat_decl_y_msgbuf[128];
@@ -1573,51 +1613,28 @@ pat_decl_y_parse ()
   PAT_DECL_Y_SIZE_T pat_decl_y_msg_alloc = sizeof pat_decl_y_msgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `pat_decl_y_ss': related to states,
-     `pat_decl_y_vs': related to semantic values,
-     `pat_decl_y_ls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow pat_decl_y_overflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  pat_decl_y_type_int16 pat_decl_y_ssa[PAT_DECL_Y_INITDEPTH];
-  pat_decl_y_type_int16 *pat_decl_y_ss = pat_decl_y_ssa;
-  pat_decl_y_type_int16 *pat_decl_y_ssp;
-
-  /* The semantic value stack.  */
-  PAT_DECL_Y_STYPE pat_decl_y_vsa[PAT_DECL_Y_INITDEPTH];
-  PAT_DECL_Y_STYPE *pat_decl_y_vs = pat_decl_y_vsa;
-  PAT_DECL_Y_STYPE *pat_decl_y_vsp;
-
-
-
 #define PAT_DECL_Y_POPSTACK(N)   (pat_decl_y_vsp -= (N), pat_decl_y_ssp -= (N))
 
-  PAT_DECL_Y_SIZE_T pat_decl_y_stacksize = PAT_DECL_Y_INITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  PAT_DECL_Y_STYPE pat_decl_y_val;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int pat_decl_y_len = 0;
 
+  pat_decl_y_token = 0;
+  pat_decl_y_ss = pat_decl_y_ssa;
+  pat_decl_y_vs = pat_decl_y_vsa;
+  pat_decl_y_stacksize = PAT_DECL_Y_INITDEPTH;
+
   PAT_DECL_Y_DPRINTF ((stderr, "Starting parse\n"));
 
   pat_decl_y_state = 0;
   pat_decl_y_errstatus = 0;
   pat_decl_y_nerrs = 0;
-  pat_decl_y_char = PAT_DECL_Y_EMPTY;		/* Cause a token to be read.  */
+  pat_decl_y_char = PAT_DECL_Y_EMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   pat_decl_y_ssp = pat_decl_y_ss;
   pat_decl_y_vsp = pat_decl_y_vs;
 
@@ -1647,7 +1664,6 @@ pat_decl_y_parse ()
 	PAT_DECL_Y_STYPE *pat_decl_y_vs1 = pat_decl_y_vs;
 	pat_decl_y_type_int16 *pat_decl_y_ss1 = pat_decl_y_ss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1655,7 +1671,6 @@ pat_decl_y_parse ()
 	pat_decl_y_overflow (PAT_DECL_Y__("memory exhausted"),
 		    &pat_decl_y_ss1, pat_decl_y_size * sizeof (*pat_decl_y_ssp),
 		    &pat_decl_y_vs1, pat_decl_y_size * sizeof (*pat_decl_y_vsp),
-
 		    &pat_decl_y_stacksize);
 
 	pat_decl_y_ss = pat_decl_y_ss1;
@@ -1678,9 +1693,8 @@ pat_decl_y_parse ()
 	  (union pat_decl_y_alloc *) PAT_DECL_Y_STACK_ALLOC (PAT_DECL_Y_STACK_BYTES (pat_decl_y_stacksize));
 	if (! pat_decl_y_ptr)
 	  goto pat_decl_y_exhaustedlab;
-	PAT_DECL_Y_STACK_RELOCATE (pat_decl_y_ss);
-	PAT_DECL_Y_STACK_RELOCATE (pat_decl_y_vs);
-
+	PAT_DECL_Y_STACK_RELOCATE (pat_decl_y_ss_alloc, pat_decl_y_ss);
+	PAT_DECL_Y_STACK_RELOCATE (pat_decl_y_vs_alloc, pat_decl_y_vs);
 #  undef PAT_DECL_Y_STACK_RELOCATE
 	if (pat_decl_y_ss1 != pat_decl_y_ssa)
 	  PAT_DECL_Y_STACK_FREE (pat_decl_y_ss1);
@@ -1691,7 +1705,6 @@ pat_decl_y_parse ()
       pat_decl_y_ssp = pat_decl_y_ss + pat_decl_y_size - 1;
       pat_decl_y_vsp = pat_decl_y_vs + pat_decl_y_size - 1;
 
-
       PAT_DECL_Y_DPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) pat_decl_y_stacksize));
 
@@ -1701,6 +1714,9 @@ pat_decl_y_parse ()
 
   PAT_DECL_Y_DPRINTF ((stderr, "Entering state %d\n", pat_decl_y_state));
 
+  if (pat_decl_y_state == PAT_DECL_Y_FINAL)
+    PAT_DECL_Y_ACCEPT;
+
   goto pat_decl_y_backup;
 
 /*-----------.
@@ -1709,16 +1725,16 @@ pat_decl_y_parse ()
 pat_decl_y_backup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   pat_decl_y_n = pat_decl_y_pact[pat_decl_y_state];
   if (pat_decl_y_n == PAT_DECL_Y_PACT_NINF)
     goto pat_decl_y_default;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* PAT_DECL_Y_CHAR is either PAT_DECL_Y_EMPTY or PAT_DECL_Y_EOF or a valid look-ahead symbol.  */
+  /* PAT_DECL_Y_CHAR is either PAT_DECL_Y_EMPTY or PAT_DECL_Y_EOF or a valid lookahead symbol.  */
   if (pat_decl_y_char == PAT_DECL_Y_EMPTY)
     {
       PAT_DECL_Y_DPRINTF ((stderr, "Reading a token: "));
@@ -1750,20 +1766,16 @@ pat_decl_y_backup:
       goto pat_decl_y_reduce;
     }
 
-  if (pat_decl_y_n == PAT_DECL_Y_FINAL)
-    PAT_DECL_Y_ACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (pat_decl_y_errstatus)
     pat_decl_y_errstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   PAT_DECL_Y__SYMBOL_PRINT ("Shifting", pat_decl_y_token, &pat_decl_y_lval, &pat_decl_y_lloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (pat_decl_y_char != PAT_DECL_Y_EOF)
-    pat_decl_y_char = PAT_DECL_Y_EMPTY;
+  /* Discard the shifted token.  */
+  pat_decl_y_char = PAT_DECL_Y_EMPTY;
 
   pat_decl_y_state = pat_decl_y_n;
   *++pat_decl_y_vsp = pat_decl_y_lval;
@@ -1803,29 +1815,39 @@ pat_decl_y_reduce:
   switch (pat_decl_y_n)
     {
         case 2:
-#line 459 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 459 "./pat_decl_y.y"
     {
 		PAT_DECL_Y_ACCEPT;
 		}
     break;
 
   case 10:
-#line 487 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 487 "./pat_decl_y.y"
     { PAT_INSPNT = pat_addpains (PAT_INSPNT, (pat_decl_y_vsp[(2) - (4)].text), (pat_decl_y_vsp[(3) - (4)].text)); }
     break;
 
   case 11:
-#line 492 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 492 "./pat_decl_y.y"
     { (pat_decl_y_val.text) = (pat_decl_y_vsp[(1) - (1)].text); }
     break;
 
   case 12:
-#line 497 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 497 "./pat_decl_y.y"
     { (pat_decl_y_val.text) = (pat_decl_y_vsp[(1) - (1)].text); }
     break;
 
   case 13:
-#line 502 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 502 "./pat_decl_y.y"
     {
 		PAT_COMPNT = pat_addpacom (PAT_COMPNT, (pat_decl_y_vsp[(1) - (1)].text), STT_NBR);
 		STT_NBR    = 0;
@@ -1833,7 +1855,9 @@ pat_decl_y_reduce:
     break;
 
   case 16:
-#line 520 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 520 "./pat_decl_y.y"
     {
 		int           length;
 		int           lclmod;
@@ -1872,7 +1896,9 @@ pat_decl_y_reduce:
     break;
 
   case 17:
-#line 567 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 567 "./pat_decl_y.y"
     {
 		int           i      ;
 		int           lclmod ;
@@ -1911,42 +1937,58 @@ pat_decl_y_reduce:
     break;
 
   case 18:
-#line 606 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 606 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'B'; }
     break;
 
   case 19:
-#line 608 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 608 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = (pat_decl_y_vsp[(1) - (1)].immd); }
     break;
 
   case 20:
-#line 613 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 613 "./pat_decl_y.y"
     { pshtab ((pat_decl_y_vsp[(1) - (1)].arra)); }
     break;
 
   case 21:
-#line 617 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 617 "./pat_decl_y.y"
     { pshtab ((pat_decl_y_vsp[(3) - (3)].arra)); }
     break;
 
   case 22:
-#line 622 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 622 "./pat_decl_y.y"
     { (pat_decl_y_val.arra) = (pat_decl_y_vsp[(1) - (1)].arra); }
     break;
 
   case 23:
-#line 624 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 624 "./pat_decl_y.y"
     { (pat_decl_y_val.arra) = (pat_decl_y_vsp[(1) - (1)].arra); }
     break;
 
   case 24:
-#line 626 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 626 "./pat_decl_y.y"
     { (pat_decl_y_val.arra) = (pat_decl_y_vsp[(1) - (1)].arra); }
     break;
 
   case 25:
-#line 631 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 631 "./pat_decl_y.y"
     {
 		(pat_decl_y_val.arra).ident = (pat_decl_y_vsp[(1) - (1)].text);
 		(pat_decl_y_val.arra).left  = -1;
@@ -1955,7 +1997,9 @@ pat_decl_y_reduce:
     break;
 
   case 26:
-#line 643 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 643 "./pat_decl_y.y"
     {
 		(pat_decl_y_val.arra).ident = (pat_decl_y_vsp[(1) - (4)].text);
 		(pat_decl_y_val.arra).left  = (pat_decl_y_vsp[(3) - (4)].valu);
@@ -1964,7 +2008,9 @@ pat_decl_y_reduce:
     break;
 
   case 27:
-#line 657 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 657 "./pat_decl_y.y"
     {
 		(pat_decl_y_val.arra).ident = (pat_decl_y_vsp[(1) - (6)].text);
 		(pat_decl_y_val.arra).left  = (pat_decl_y_vsp[(3) - (6)].valu);
@@ -1973,7 +2019,9 @@ pat_decl_y_reduce:
     break;
 
   case 28:
-#line 667 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 667 "./pat_decl_y.y"
     {
 		char name [256];
 		int  i         ;
@@ -1990,37 +2038,51 @@ pat_decl_y_reduce:
     break;
 
   case 30:
-#line 687 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 687 "./pat_decl_y.y"
     { pshnam ((pat_decl_y_vsp[(3) - (3)].text)); }
     break;
 
   case 33:
-#line 697 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 697 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'I'; }
     break;
 
   case 34:
-#line 699 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 699 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'O'; }
     break;
 
   case 35:
-#line 701 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 701 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'T'; }
     break;
 
   case 36:
-#line 703 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 703 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'S'; }
     break;
 
   case 37:
-#line 705 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 705 "./pat_decl_y.y"
     { (pat_decl_y_val.immd) = 'R'; }
     break;
 
   case 38:
-#line 710 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 710 "./pat_decl_y.y"
     {
 		if (ERR_FLG > 30)
 		  PAT_DECL_Y_ABORT;
@@ -2030,28 +2092,37 @@ pat_decl_y_reduce:
     break;
 
   case 39:
-#line 720 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 720 "./pat_decl_y.y"
     { (pat_decl_y_val.valu) = 0 ;           }
     break;
 
   case 40:
-#line 722 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 722 "./pat_decl_y.y"
     { (pat_decl_y_val.valu) = PAT_IOL__SPY; }
     break;
 
   case 41:
-#line 727 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 727 "./pat_decl_y.y"
     { (pat_decl_y_val.valu) = 0 ;             }
     break;
 
   case 42:
-#line 729 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1455 of yacc.c  */
+#line 729 "./pat_decl_y.y"
     { (pat_decl_y_val.valu) = PAT_IOL__TRACE; }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2055 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2126 "y.tab.c"
       default: break;
     }
   PAT_DECL_Y__SYMBOL_PRINT ("-> $$ =", pat_decl_y_r1[pat_decl_y_n], &pat_decl_y_val, &pat_decl_y_loc);
@@ -2062,7 +2133,6 @@ pat_decl_y_reduce:
 
   *++pat_decl_y_vsp = pat_decl_y_val;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2127,7 +2197,7 @@ pat_decl_y_errlab:
 
   if (pat_decl_y_errstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (pat_decl_y_char <= PAT_DECL_Y_EOF)
@@ -2144,7 +2214,7 @@ pat_decl_y_errlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto pat_decl_y_errlab1;
 
@@ -2201,9 +2271,6 @@ pat_decl_y_errlab1:
       PAT_DECL_Y__STACK_PRINT (pat_decl_y_ss, pat_decl_y_ssp);
     }
 
-  if (pat_decl_y_n == PAT_DECL_Y_FINAL)
-    PAT_DECL_Y_ACCEPT;
-
   *++pat_decl_y_vsp = pat_decl_y_lval;
 
 
@@ -2228,7 +2295,7 @@ pat_decl_y_abortlab:
   pat_decl_y_result = 1;
   goto pat_decl_y_return;
 
-#ifndef pat_decl_y_overflow
+#if !defined(pat_decl_y_overflow) || PAT_DECL_Y_ERROR_VERBOSE
 /*-------------------------------------------------.
 | pat_decl_y_exhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2239,7 +2306,7 @@ pat_decl_y_exhaustedlab:
 #endif
 
 pat_decl_y_return:
-  if (pat_decl_y_char != PAT_DECL_Y_EOF && pat_decl_y_char != PAT_DECL_Y_EMPTY)
+  if (pat_decl_y_char != PAT_DECL_Y_EMPTY)
      pat_decl_y_destruct ("Cleanup: discarding lookahead",
 		 pat_decl_y_token, &pat_decl_y_lval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2265,6 +2332,8 @@ pat_decl_y_return:
 }
 
 
-#line 731 "../../../src/ppt/src/pat_decl_y.y"
+
+/* Line 1675 of yacc.c  */
+#line 731 "./pat_decl_y.y"
 
 
