@@ -1,5 +1,5 @@
 /*
- *  $Id: LEF_drive_sxlib.h,v 1.1.1.1 2002/04/25 16:16:20 jpc Exp $
+ *  $Id: LEF_drive_sxlib.h,v 1.3 2003/05/19 16:16:41 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -7,7 +7,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Header  :         "./LEF_drive_sxlib.h"                     |
  *  | ************************************************************** |
@@ -25,6 +25,7 @@
 #   define  F_NO_POWER_GEOM        0x00000002
 #   define  F_POWER_ABUTMENT       0x00000004
 #   define  F_POWER_FEEDTHRU       0x00000008
+#   define  F_NO_SPLIT_TERM        0x00000010
 
 
   extern void  lefsavesxlophfig (struct lofig *apLofig,
