@@ -1,5 +1,5 @@
 /*
- *  $Id: a2DEF.c,v 1.1.1.1 2002/04/25 16:16:19 jpc Exp $
+ *  $Id: a2DEF.c,v 1.3 2003/06/26 17:00:39 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -7,7 +7,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Module    :         "./a2DEF.c"                             |
  *  | ************************************************************** |
@@ -199,15 +199,19 @@ extern int main(argc, argv)
 
     /* Short options. */
     if (!strcmp (argv[i], "-c")) {
-      argFlags |=  A_FIXED_PINS;
-      defFlags |=  F_FIXED_PINS;
+      /* Deprecated.
+       * argFlags |=  A_FIXED_PINS;
+       * defFlags |=  F_FIXED_PINS;
+       */
       /*macFlags |=  F_MAC_FIXED_PINS;*/
       continue;
     }
 
     if (!strcmp (argv[i], "-b")) {
-      argFlags &= ~A_FIXED_PINS;
-      defFlags &= ~F_FIXED_PINS;
+      /* Deprecated.
+       * argFlags &= ~A_FIXED_PINS;
+       * defFlags &= ~F_FIXED_PINS;
+       */
       continue;
     }
 
