@@ -1,6 +1,6 @@
 
 /*
- *  $Id: util_MBK.c,v 1.3 2003/09/16 10:14:38 jpc Exp $
+ *  $Id: util_MBK.c,v 1.5 2005/02/17 15:34:44 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -1087,11 +1087,11 @@ extern long  cmpSigName(apLoSig, asName)
  *  Function  :  "addInsLoCon()".
  */
 
-extern locon_list *addInsLoCon(apIns, asName, apSig, aDir)
-  loins_list *apIns;
-        char *asName;
-  losig_list *apSig;
-        char  aDir;
+extern struct locon *addInsLoCon(apIns, asName, apSig, aDir)
+  struct loins *apIns;
+          char *asName;
+  struct losig *apSig;
+          char  aDir;
 {
   locon_list *pCon;
         char *sName;
@@ -1464,7 +1464,7 @@ extern void  addfeed (apLofig, apPhfig)
 
   sigVSS = apLofig->LOSIG;
   while (sigVSS != NULL) {
-    if (isvdd (getsigname (sigVSS))) break;
+    if (isvss (getsigname (sigVSS))) break;
     sigVSS = sigVSS->NEXT;
   }
 
